<?php

namespace ROOFERPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;
use Elementor\Utils;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Blog_Grid extends Widget_Base {

	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'roofer_blog_grid';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Blog Grid', 'roofer' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-post';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'roofer' ];
	}
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'blog_grid',
			[
				'label' => esc_html__( 'Blog Grid', 'roofer' ),
			]
		);

		$this->add_control(
			'style',
			[
				'label'   => esc_html__( 'Select Style', 'rashid' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'style1',
				'options' => array(
					'style1'   => esc_html__( 'Style One', 'rashid' ),
					'style2'   => esc_html__( 'Style Two', 'rashid' ),
					'style3'   => esc_html__( 'Style Three', 'rashid' ),
				),
			]
		);

		$this->add_control(
            'thumb', 
				[
					'label'   => esc_html__( 'Choose Post Image', 'constech' ),
					'label_block' => true,
					'type'    => Controls_Manager::SELECT,
					'default' => 'style1',
					'options' => array(
						'style1' => esc_html__( 'Meta Box Image', 'constech' ),
						'style2' => esc_html__( 'Dafult Thumbnail', 'constech' ),
					),
				]
		);
		
		
		$this->add_control(
			'bttn',
			[
				'label'       => __( 'Button', 'roofer' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => esc_html__( 'Enter your Button Title', 'roofer' ),
				'default' => esc_html__('Read More', 'roofer'),
			]
		);	
		$this->add_control(
			'column',
			[
				'label'   => esc_html__( 'Column', 'roofer' ),
				'type'    => Controls_Manager::SELECT,
				'default' => '3',
				'options' => array(
					'12'   => esc_html__( 'One Column', 'roofer' ),
					'6'   => esc_html__( 'Two Column', 'roofer' ),
					'4'   => esc_html__( 'Three Column', 'roofer' ),
					'3'   => esc_html__( 'Four Column', 'roofer' ),
					'2'   => esc_html__( 'Six Column', 'roofer' ),
				),
			]
		);
		$this->add_control(
			'sec_class',
			[
				'label'       => __( 'Section Class', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter Section Class', 'rashid' ),
			]
		);
		
		
		$this->end_controls_section();
	
		$this->start_controls_section(
				'content_section',
				[
					'label' => __( 'Blog Block', 'roofer' ),
					'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
				]
			);
			
		
		$this->add_control(
			'text_limit',
			[
				'label'   => esc_html__( 'Text Limit', 'roofer' ),
				'type'    => Controls_Manager::NUMBER,
				'default' => 15,
				'min'     => 1,
				'max'     => 100,
				'step'    => 1,
			]
		);
		$this->add_control(
			'query_number',
			[
				'label'   => esc_html__( 'Number of post', 'roofer' ),
				'type'    => Controls_Manager::NUMBER,
				'default' => 3,
				'min'     => 1,
				'max'     => 100,
				'step'    => 1,
			]
		);
		$this->add_control(
			'query_orderby',
			[
				'label'   => esc_html__( 'Order By', 'roofer' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'date',
				'options' => array(
					'date'       => esc_html__( 'Date', 'roofer' ),
					'title'      => esc_html__( 'Title', 'roofer' ),
					'menu_order' => esc_html__( 'Menu Order', 'roofer' ),
					'rand'       => esc_html__( 'Random', 'roofer' ),
				),
			]
		);
		$this->add_control(
			'query_order',
			[
				'label'   => esc_html__( 'Order', 'roofer' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'DESC',
				'options' => array(
					'DESc' => esc_html__( 'DESC', 'roofer' ),
					'ASC'  => esc_html__( 'ASC', 'roofer' ),
				),
			]
		);
		$this->add_control(
			'query_exclude',
			[
				'label'       => esc_html__( 'Exclude', 'roofer' ),
				'type'        => Controls_Manager::TEXT,
				'description' => esc_html__( 'Exclude posts, pages, etc. by ID with comma separated.', 'roofer' ),
			]
		);
		$this->add_control(
            'query_category', 
				[
				  'type' => Controls_Manager::SELECT,
				  'label' => esc_html__('Category', 'roofer'),
				  'options' => get_blog_categories()
				]
		);

		$this->add_control(
			'bttn',
			[
				'label'       => __( 'Button', 'rashid' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => esc_html__( 'Enter your Button Title', 'rashid' ),
				'default' => esc_html__('Read More', 'rashid'),
			]
		);	
		
		$this->end_controls_section();

	}

	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
        
        $paged = roofer_set($_POST, 'paged') ? esc_attr($_POST['paged']) : 1;

		$this->add_render_attribute( 'wrapper', 'class', 'templatepath-roofer' );
		$args = array(
			'post_type'      => 'post',
			'posts_per_page' => roofer_set( $settings, 'query_number' ),
			'orderby'        => roofer_set( $settings, 'query_orderby' ),
			'order'          => roofer_set( $settings, 'query_order' ),
			'paged'         => $paged
		);
		if ( roofer_set( $settings, 'query_exclude' ) ) {
			$settings['query_exclude'] = explode( ',', $settings['query_exclude'] );
			$args['post__not_in']      = roofer_set( $settings, 'query_exclude' );
		}
		if( roofer_set( $settings, 'query_category' ) ) $args['category_name'] = roofer_set( $settings, 'query_category' );
		$query = new \WP_Query( $args );

		if ( $query->have_posts() ) 
		{ ?>

	<?php  if ( 'style1' === $settings['style'] ) : ?>	
	<section class="blog-style-one <?php echo esc_attr($settings['sec_class']);?>">
        <div class="container">
			<?php if($settings['title']): ?>
            <div class="sec-title text-center">
                <span><?php echo $settings['subtitle'];?></span>
                <h2><?php echo $settings['title'];?></h2>
            </div>
			<?php endif; ?>
            <div class="row">

				<?php while ( $query->have_posts() ) : $query->the_post();
					$meta_image = get_post_meta( get_the_id(), 'meta_image', true );
					?>

                <div class="col-lg-<?php echo esc_attr($settings['column'], true );?> col-md-12 col-sm-12 col-xs-12">
                    <div class="single-blog-style-one">
                        <div class="text-box hvr-sweep-to-bottom">
                            <div class="meta-info">
                                <a href="<?php echo esc_url(get_author_posts_url( get_the_author_meta('ID') )); ?>">by <?php the_author(); ?></a><!--
                                --><span class="sep">-</span><!--
                                --><a href="<?php echo esc_url( the_permalink( get_the_id() ) );?>"><?php echo get_the_date(); ?></a>
                            </div>
                            <h3><a href="<?php echo esc_url( the_permalink( get_the_id() ) );?>"><?php the_title(); ?></a></h3>
                            <a href="<?php echo esc_url( the_permalink( get_the_id() ) );?>" class="read-more"><?php echo $settings['bttn'];?></a>
                        </div>
                        <div class="image-box">
                            
							<a href="<?php echo esc_url( the_permalink( get_the_id() ) );?>">
								<?php  if ( 'style1' === $settings['thumb'] ) : ?>
								<img src="<?php echo wp_get_attachment_url($meta_image['id']);?>" alt="" />
								<?php endif; ?> 
								<?php  if ( 'style2' === $settings['thumb'] ) : ?>      
								<?php  the_post_thumbnail();    ?>
								<?php endif; ?> 
							</a>

                            <div class="box">
                                <a href="<?php echo esc_url( the_permalink( get_the_id() ) );?>" class="more-btn"><i class="fa fa-arrow-right"></i></a>
                            </div>
                        </div>
                    </div>
                </div>
				<?php endwhile; ?>    
            </div>
        </div> 
    </section>
	<?php endif;?>								

	<?php  if ( 'style2' === $settings['style'] ) : ?>

		<section class="service-style-five <?php echo esc_attr($settings['sec_class']);?>">
        <div class="container">
			<?php if($settings['title']): ?>
            <div class="sec-title text-center">
                <span><?php echo $settings['subtitle'];?></span>
                <h2><?php echo $settings['title'];?></h2>
            </div>
			<?php endif; ?>
            <div class="row">
				<?php while ( $query->have_posts() ) : $query->the_post();
					$meta_image = get_post_meta( get_the_id(), 'meta_image', true );
					?>
                <div class="col-lg-<?php echo esc_attr($settings['column'], true );?> col-md-6 col-sm-12 col-xs-12">
                    <div class="single-service-five">
                        <div class="image-box">
							<a href="<?php echo esc_url( the_permalink( get_the_id() ) );?>">
								<?php  if ( 'style1' === $settings['thumb'] ) : ?>
								<img src="<?php echo wp_get_attachment_url($meta_image['id']);?>" alt="" />
								<?php endif; ?> 
								<?php  if ( 'style2' === $settings['thumb'] ) : ?>      
								<?php  the_post_thumbnail();    ?>
								<?php endif; ?> 
							</a>
                            <div class="box">
                                <a href="<?php echo esc_url( the_permalink( get_the_id() ) );?>" class="more-btn"><i class="fa fa-arrow-right"></i></a>
                            </div><!-- /.box -->
                        </div><!-- /.image-box -->
                        <div class="text-box">
                            <h3><a href="<?php echo esc_url( the_permalink( get_the_id() ) );?>"><?php the_title(); ?></a></h3>
                            <p><?php echo roofer_trim(get_the_content(), $settings['text_limit']); ?></p>
                            <a href="<?php echo esc_url( the_permalink( get_the_id() ) );?>" class="read-more"><?php echo $settings['bttn'];?></a>
                        </div><!-- /.text-box -->
                    </div><!-- /.single-service-five -->
                </div><!-- /.col-lg-4 -->
				<?php endwhile; ?> 
            </div><!-- /.row -->
        </div><!-- /.container -->
    </section><!-- /.service-style-five -->

	<?php endif;?>
	
	

	<?php  if ( 'style3' === $settings['style'] ) : ?>								
		<section class="blog-style-one news-page news-page-sidebar <?php echo esc_attr($settings['sec_class']);?>">
			<div class="container">
				<div class="row">
					<div class="col-lg-12">
						<div class="row masonary-layout">
							<?php while ( $query->have_posts() ) : $query->the_post();
								$meta_image = get_post_meta( get_the_id(), 'meta_image', true );
								?>
								<div class="col-lg-<?php echo esc_attr($settings['column'], true );?> col-md-6 col-sm-12 col-xs-12 masonary-item">
									<div class="single-blog-style-one">                        
										<div class="image-box">
											<a href="<?php echo esc_url( the_permalink( get_the_id() ) );?>">
												<?php  if ( 'style1' === $settings['thumb'] ) : ?>
												<img src="<?php echo wp_get_attachment_url($meta_image['id']);?>" alt="" />
												<?php endif; ?> 
												<?php  if ( 'style2' === $settings['thumb'] ) : ?>      
												<?php  the_post_thumbnail();    ?>
												<?php endif; ?> 
											</a>
											<div class="box">
												<a href="<?php echo esc_url( the_permalink( get_the_id() ) );?>" class="more-btn"><i class="fa fa-arrow-right"></i></a>
											</div><!-- /.box -->
										</div><!-- /.image-box -->
										<div class="text-box">
											<a href="<?php echo esc_url(get_author_posts_url( get_the_author_meta('ID') )); ?>"><?php the_author(); ?>
											<span class="sep">-</span>		
											<a href="<?php echo esc_url(get_author_posts_url( get_the_author_meta('ID') )); ?>"><?php echo get_the_date(); ?></a>
											<h3><a href="<?php echo esc_url( the_permalink( get_the_id() ) );?>"><?php the_title(); ?></a></h3>
											<a href="<?php echo esc_url( the_permalink( get_the_id() ) );?>" class="read-more"><?php echo $settings['bttn'];?></a>
										</div>
									</div>
								</div>
							<?php endwhile; ?> 
						</div>
					</div>	
				</div>
			</div>
		</section>
	<?php endif;?>



        <?php }
		wp_reset_postdata();
	}

}