<?php

namespace ROOFERPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Contact extends Widget_Base {

	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'roofer_contact';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Contact', 'roofer' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fa fa-briefcase';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'roofer' ];
	}
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */


	protected function register_controls() {
		$this->start_controls_section(
			'contact',
			[
				'label' => esc_html__( 'Contact', 'roofer' ),
			]
		);
		
		$this->add_control(
			'style',
			[
				'label'   => esc_html__( 'Select Style', 'rashid' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'style1',
				'options' => array(
					'style1'   => esc_html__( 'Style One', 'rashid' ),
					'style2'   => esc_html__( 'Style Two', 'rashid' ),
				),
			]
		);

		$this->add_control(
			'sec_class',
			[
				'label'       => __( 'Section Class', 'roofer' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter Section Class', 'roofer' ),
			]
		);
		
		$this->end_controls_section();
		
		// New Tab#1

		$this->start_controls_section(
					'content_section',
					[
						'label' => __( 'Slider Block', 'roofer' ),
						'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
					]
				);
				$this->add_control(
				  'repeat', 
					[
						'type' => Controls_Manager::REPEATER,
						'seperator' => 'before',
						'default' => 
							[
								['block_title' => esc_html__('Projects Completed', 'roofer')],
							],
						'fields' =>
						
							[	
								
								'block_title'=>

								[
									'name' => 'block_title',
									'label' => esc_html__('Title', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],

								'block_icons'=>
								[
									'name' => 'block_icons',
									'label' => esc_html__('Enter The icons', 'rashid'),
									'type' => Controls_Manager::ICONS,							
								],

								'block_text'=>

								[
									'name' => 'block_text',
									'label' => esc_html__('Text', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],


								'block_icons2'=>
								[
									'name' => 'block_icons2',
									'label' => esc_html__('Enter The icons', 'rashid'),
									'type' => Controls_Manager::ICONS,							
								],

								'block_text2'=>

								[
									'name' => 'block_text2',
									'label' => esc_html__('Text', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],


								'block_icons3'=>
								[
									'name' => 'block_icons3',
									'label' => esc_html__('Enter The icons', 'rashid'),
									'type' => Controls_Manager::ICONS,							
								],

								'block_text3'=>

								[
									'name' => 'block_text3',
									'label' => esc_html__('Text', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],

	

									
							],
						'title_field' => '{{block_title}}',
					 ]
			);
				
				
		$this->end_controls_section();	
					
		
	}

	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	 
	protected function render() {
		$settings = $this->get_settings_for_display();
		$allowed_tags = wp_kses_allowed_html('post');
		?>
        	

	<?php
	  echo '
	 <script>
 jQuery(document).ready(function($)
 {

//put the js code under this line 
if ($(".sales-carousel").length) {
	$(".sales-carousel").owlCarousel({
		loop: false,
		margin: 30,
		nav: false,
		dots: true,
		autoWidth: false,
		autoplay: true,
		smartSpeed: 700,
		autoplayTimeout: 5000,
		autoplayHoverPause: true,
		responsive: {
			0: {
				items: 1
			},
			480: {
				items: 1
			},
			767: {
				items: 1
			},
			991: {
				items: 2
			},
			1000: {
				items: 3
			},
			1200: {
				items: 3
			}
		}
	});
}



//put the code above the line 

  });
</script>';


?>

<?php  if ( 'style1' === $settings['style'] ) : ?>
	<section class="roofer-sales-point <?php echo esc_attr($settings['sec_class']);?>">
        <div class="container">
            <div class="sales-carousel owl-carousel owl-theme">
			<?php foreach($settings['repeat'] as $item):?>	

            	<div class="item">
            		<div class="single-sales-point">
            			<div class="map-box">
            				<div 
					          class="google-map" 
					          id="sales-google-map-1" 
					          data-map-lat="48.379433" 
					          data-map-lng="31.165581"
					          data-icon-path="images/marker-1-1.png"
					          data-map-title="Brooklyn, New York, United Kingdom"
					          data-map-zoom="15"
					          data-markers='{
					                    "marker-1": [48.379433, 31.165581, "<h4>Main Office</h4><p>Ukraine Branch , Ukine, Ukraine</p>"]
					                }'>

					         </div>
            			</div>
            			<div class="text-box">
            				<h3><?php echo wp_kses($item['block_title'], $allowed_tags);?></h3>
            				<ul class="info-list">
								<li><i class="<?php echo str_replace("icon ", " ", esc_attr( $item['block_icons']['value']));?>"></i><?php echo wp_kses($item['block_text'], $allowed_tags);?></li>
								<li><i class="<?php echo str_replace("icon ", " ", esc_attr( $item['block_icons2']['value']));?>"></i><?php echo wp_kses($item['block_text2'], $allowed_tags);?></li>
								<li><i class="<?php echo str_replace("icon ", " ", esc_attr( $item['block_icons3']['value']));?>"></i><?php echo wp_kses($item['block_text3'], $allowed_tags);?></li>
            				</ul>
            			</div>
            		</div>
            	</div>
				<?php endforeach; ?>
            </div>
        </div>
	</section>
<?php endif ;?>	

<?php  if ( 'style2' === $settings['style'] ) : ?>
	<div class="roofer-sales-point home-six <?php echo esc_attr($settings['sec_class']);?>">
        <div class="container my-auto">
            <div class="sales-carousel owl-carousel owl-theme">
			<?php foreach($settings['repeat'] as $item):?>	

                <div class="item">
                    <div class="single-sales-point">
                        <div class="map-box">
                            <div 
                              class="google-map" 
                              id="sales-google-map-1" 
                              data-map-lat="48.379433" 
                              data-map-lng="31.165581"
                              data-icon-path="images/marker-1-1.png"
                              data-map-title="Brooklyn, New York, United Kingdom"
                              data-map-zoom="15"
                              data-markers='{
                                        "marker-1": [48.379433, 31.165581, "<h4>Main Office</h4><p>Ukraine Branch , Ukine, Ukraine</p>"]
                                    }'>

                             </div>
                        </div><!-- /.map-box -->
                        <div class="text-box">
            				<h3><?php echo wp_kses($item['block_title'], $allowed_tags);?></h3>
            				<ul class="info-list">
								<li><i class="<?php echo str_replace("icon ", " ", esc_attr( $item['block_icons']['value']));?>"></i><?php echo wp_kses($item['block_text'], $allowed_tags);?></li>
								<li><i class="<?php echo str_replace("icon ", " ", esc_attr( $item['block_icons2']['value']));?>"></i><?php echo wp_kses($item['block_text2'], $allowed_tags);?></li>
								<li><i class="<?php echo str_replace("icon ", " ", esc_attr( $item['block_icons3']['value']));?>"></i><?php echo wp_kses($item['block_text3'], $allowed_tags);?></li>
            				</ul>
            			</div>
                    </div><!-- /.single-sales-point -->
                </div><!-- /.item -->

                <?php endforeach; ?>
            </div><!-- /.row -->
        </div><!-- /.container -->
    </div><!-- /.roofer-sales-point -->
<?php endif ;?>	
	
		<?php 
	}

}