<?php

namespace ROOFERPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Faq extends Widget_Base {

	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'roofer_faq';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Faq', 'roofer' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fa fa-briefcase';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'roofer' ];
	}
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'faq',
			[
				'label' => esc_html__( 'Faq', 'roofer' ),
			]
		);
		$this->add_control(
			'sec_class',
			[
				'label'       => __( 'Section Class', 'roofer' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter Section Class', 'roofer' ),
			]
		);	

		$this->add_control(
			'image',
				[
				  'label' => __( 'Image', 'rashid' ),
				  'type' => Controls_Manager::MEDIA,
				  'default' => ['url' => Utils::get_placeholder_image_src(),],
				]
		);	
		
		$this->add_control(
			'alt_text',
			[
				'label'       => __( 'Alt text', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Description', 'rashid' ),
			]
		);

		$this->add_control(
			'text',
			[
				'label'       => __( 'Description Text', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Description', 'rashid' ),
			]
		);
		
		$this->end_controls_section();
		
		// New Tab#1

		$this->start_controls_section(
					'content_section',
					[
						'label' => __( 'Feature Block', 'roofer' ),
						'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
					]
				);

				
				$this->add_control(
				  'repeat', 
					[
						'type' => Controls_Manager::REPEATER,
						'seperator' => 'before',
						'default' => 
							[
								['block_title' => esc_html__('Projects Completed', 'roofer')],
							],
						'fields' => 
							[								
									
								'block_title'=>

									[
										'name' => 'block_title',
										'label' => esc_html__('Title', 'roofer'),
										'type' => Controls_Manager::TEXTAREA,
										'default' => esc_html__('', 'roofer')
									],

										'block_text'=>
									
									[
										'name' => 'block_text',
										'label' => esc_html__('Text', 'roofer'),
										'type' => Controls_Manager::TEXTAREA,
										'default' => esc_html__('', 'roofer')
									],											

							],

						'title_field' => '{{block_title}}',
					 ]
			);
				
				
		$this->end_controls_section();	
						
		
		}

	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	 
	protected function render() {
		$settings = $this->get_settings_for_display();
		$allowed_tags = wp_kses_allowed_html('post');
		?>



		<section class="faq-style-one <?php echo esc_attr($settings['sec_class']);?>">
        <div class="container">
            <div class="row">
                <div class="col-xl-6">
                    <div class="faq-image-box">
							<?php  if ( esc_url($settings['image']['id']) ) : ?>   
								<img src="<?php echo wp_get_attachment_url($settings['image']['id']);?>" alt="<?php echo esc_attr($settings['alt_text']);?>"/>
								<?php else :?>
								<div class="noimage"></div>
							<?php endif;?>
                        <div class="box"><?php echo $settings['text'];?></div>
                    </div>
                </div>
                <div class="col-xl-6">
                    <div class="accrodion-grp" data-grp-name="faq-accrodion">
					<?php foreach($settings['repeat'] as $key=>$item):?>
							<div class="accrodion <?php if($key == 1) echo 'active';?>">
								<div class="accrodion-title">
									<h4><?php echo wp_kses($item['block_title'], $allowed_tags);?></h4>
								</div>
								<div class="accrodion-content">
									<div class="inner">
										<p><?php echo wp_kses($item['block_text'], $allowed_tags);?></p>
									</div>
								</div>
							</div>
						<?php endforeach; ?>                       
                    </div>
                </div>
            </div>
        </div>
    </section>

             
		<?php 
	}

}