<?php

namespace ROOFERPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class How_We_Works extends Widget_Base {

	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'roofer_how_we_works';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'How We Works', 'roofer' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fa fa-briefcase';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'roofer' ];
	}
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'how_we_works',
			[
				'label' => esc_html__( 'How We Works', 'roofer' ),
			]
		);

		$this->add_control(
			'sec_class',
			[
				'label'       => __( 'Section Class', 'roofer' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter Section Class', 'roofer' ),
			]
		);
		
		$this->end_controls_section();
		
		// New Tab#1

		$this->start_controls_section(
					'content_section',
					[
						'label' => __( 'Slider Block', 'roofer' ),
						'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
					]
				);

				$this->add_control(
				  'repeat', 
					[
						'type' => Controls_Manager::REPEATER,
						'seperator' => 'before',
						'default' => 
							[
								['block_title' => esc_html__('Projects Completed', 'roofer')],
							],
						'fields' => 

							[	

								'block_title'=>
								[
									'name' => 'block_title',
									'label' => esc_html__('Title', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],
								
								'block_image'=>
								[
									'name' => 'block_image',
									'label' => __( 'Image', 'rashid' ),
									'type' => Controls_Manager::MEDIA,
									'default' => ['url' => Utils::get_placeholder_image_src(),],
								  ],	
						  

								  'block_alt_text'=>
								  [
								  'name' => 'block_alt_text',
								  'label' => esc_html__('Image Text', 'rashid'),
								  'type' => Controls_Manager::TEXTAREA,
								  'default' => esc_html__('', 'rashid')
								  ],	

								  'block_title2'=>
								[
									'name' => 'block_title2',
									'label' => esc_html__('Title', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],

								'block_subtitle'=>
								[
									'name' => 'block_subtitle',
									'label' => esc_html__('Subtitle', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],
								
								'block_text'=>
								[
									'name' => 'block_text',
									'label' => esc_html__('Text', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],


								'block_btnlink'=>
								[
									'name' => 'block_btnlink',
									'label' => __( 'Button Url', 'rashid' ),
									'type' => Controls_Manager::URL,
									'placeholder' => __( 'https://your-link.com', 'rashid' ),
									'show_external' => true,
									'default' => [
										'url' => '',
										'is_external' => true,
										'nofollow' => true,
									],
								],

		
								'block_button'=>
								[
									'name' => 'block_button',
									'label'       => __( 'Button', 'rashid' ),
									'type'        => Controls_Manager::TEXT,
									'dynamic'     => [
										'active' => true,
									],
									'placeholder' => __( 'Enter your Button Title', 'rashid' ),
									'default' => esc_html__('Read More', 'rashid'),
								],


								'block_text2'=>
								[
									'name' => 'block_text2',
									'label' => esc_html__('Text', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],

								'block_text3'=>
								[
									'name' => 'block_text3',
									'label' => esc_html__('Text', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],


								'block_image2'=>
								[
									'name' => 'block_image2',
									'label' => __( 'Image', 'rashid' ),
									'type' => Controls_Manager::MEDIA,
									'default' => ['url' => Utils::get_placeholder_image_src(),],
								],	
						

								'block_alt_text2'=>
								[
								'name' => 'block_alt_text2',
								'label' => esc_html__('Image Text', 'rashid'),
								'type' => Controls_Manager::TEXTAREA,
								'default' => esc_html__('', 'rashid')
								],


								'block_title3'=>
								[
									'name' => 'block_title3',
									'label' => esc_html__('Title', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],

								  'block_text4'=>
								[
									'name' => 'block_text4',
									'label' => esc_html__('Text', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],

								'block_text5'=>
								[
									'name' => 'block_text5',
									'label' => esc_html__('Text', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],

								'block_title4'=>
								[
									'name' => 'block_title4',
									'label' => esc_html__('Title', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],

								'block_text6'=>
								[
									'name' => 'block_text6',
									'label' => esc_html__('Text', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],


								'block_btnlink2'=>
								[
									'name' => 'block_btnlink2',
									'label' => __( 'Button Url', 'rashid' ),
									'type' => Controls_Manager::URL,
									'placeholder' => __( 'https://your-link.com', 'rashid' ),
									'show_external' => true,
									'default' => [
										'url' => '',
										'is_external' => true,
										'nofollow' => true,
									],
								],

		
								'block_button2'=>
								[
									'name' => 'block_button2',
									'label'       => __( 'Button', 'rashid' ),
									'type'        => Controls_Manager::TEXT,
									'dynamic'     => [
										'active' => true,
									],
									'placeholder' => __( 'Enter your Button Title', 'rashid' ),
									'default' => esc_html__('Read More', 'rashid'),
								],


								'block_text7'=>
								[
									'name' => 'block_text7',
									'label' => esc_html__('Text', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],


								'block_icons'=>
								[
									'name' => 'block_icons',
									'label' => esc_html__('Enter The icons', 'rashid'),
									'type' => Controls_Manager::ICONS,							
								],

								
									
							],
						'title_field' => '{{block_title}}',
					 ]
			);
				
				
		$this->end_controls_section();	
					
		
		}

	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	 
	protected function render() {
		$settings = $this->get_settings_for_display();
		$allowed_tags = wp_kses_allowed_html('post');
		?>
        	

	<?php
	  echo '
	 <script>
 jQuery(document).ready(function($)
 {

//put the js code under this line 


//put the code above the line 

  });
</script>';


?>

	<section class="how-we-work-tab <?php echo esc_attr($settings['sec_class']);?>">
        <div class="container">
            <ul class="nav nav-tabs tab-title clearfix" role="tablist">
				<?php foreach($settings['repeat'] as $key=>$item):?>
					<li class="nav-item">
						<a class="nav-link <?php if($key == 0) echo 'active';?>" href="#plan-<?php echo esc_attr($key);?>" role="tab" data-toggle="tab">
							<?php echo wp_kses($item['block_title'], $allowed_tags);?>
						</a>
					</li>
				<?php endforeach; ?>
            </ul>

            <div class="tab-content">
				<?php foreach($settings['repeat'] as $key=>$item):?>
					<div role="tabpanel" class="tab-pane fade show <?php if($key == 1) echo 'active';?>" id="plan-<?php echo esc_attr($key);?>">
						<div class="row low-gutter">
							<div class="col-xl-8">
								<div class="content-box clearfix gray-bg people-box">
									<div class="img-box">
										<?php if(wp_get_attachment_url($item['block_image']['id'])): ?>
											<img src="<?php echo wp_get_attachment_url($item['block_image']['id']);?>" alt="<?php echo wp_kses($item['block_alt_text'], $allowed_tags);?>">
											<?php else :?>
											<div class="noimage"></div>
										<?php endif;?>
									</div>
									<div class="text-box">
										<h3><?php echo wp_kses($item['block_title2'], $allowed_tags);?></h3>
										<span><?php echo wp_kses($item['block_subtitle'], $allowed_tags);?></span>
										<p class="large-paragraph"><?php echo wp_kses($item['block_text'], $allowed_tags);?></p>
										<a href="<?php echo esc_url($item['block_btnlink']['url']);?>" class="read-more"><?php echo wp_kses($item['block_button'], $allowed_tags);?></a>
									</div>
								</div>
								<div class="content-box clearfix gray-bg tech-box">
									<div class="outer-box"><?php echo wp_kses($item['block_text2'], $allowed_tags);?></div>
									<div class="outer-box equal-box"><?php echo wp_kses($item['block_text3'], $allowed_tags);?></div>
									<div class="img-box">
										<?php if(wp_get_attachment_url($item['block_image2']['id'])): ?>
											<img src="<?php echo wp_get_attachment_url($item['block_image2']['id']);?>" alt="<?php echo wp_kses($item['block_alt_text2'], $allowed_tags);?>">
											<?php else :?>
											<div class="noimage"></div>
										<?php endif;?>
									</div>
									<div class="text-box">
										<h3><?php echo wp_kses($item['block_title3'], $allowed_tags);?></h3>
										<div class="row">
											<div class="col-lg-6 col-md-12">
												<ul class="list-items">
													<?php echo wp_kses($item['block_text4'], $allowed_tags);?>
												</ul>
											</div>
											<div class="col-lg-6 col-md-12">
												<ul class="list-items">
													<?php echo wp_kses($item['block_text5'], $allowed_tags);?>
												</ul>
											</div>
										</div>
									</div>
								</div>
							</div>
							<div class="col-xl-4">
								<div class="content-box gray-bg person-box">
									<h3><?php echo wp_kses($item['block_title4'], $allowed_tags);?></h3>
									<p class="large-paragraph"><?php echo wp_kses($item['block_text6'], $allowed_tags);?></p>
									<div class="btn-box">
										<a href="<?php echo esc_url($item['block_btnlink2']['url']);?>" class="thm-btn"><?php echo wp_kses($item['block_button2'], $allowed_tags);?></a>
										<div class="btn-tag-line"><?php echo wp_kses($item['block_text7'], $allowed_tags);?> <i class="<?php echo str_replace("icon ", " ", esc_attr( $item['block_icons']['value']));?>"></i></div>
									</div>
								</div>
							</div>
						</div>
					</div>
				<?php endforeach; ?>
            </div>
        </div>
    </section> 
             
		<?php 
	}

}