<?php

namespace ROOFERPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Slider2 extends Widget_Base {

	/**
	 * Get widget name. 
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'roofer_slider2';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Slider2', 'roofer' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fa fa-briefcase';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'roofer' ];
	}
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'slider2',
			[
				'label' => esc_html__( 'Slider2', 'roofer' ),
			]
		);
		$this->add_control(
			'sec_class',
			[
				'label'       => __( 'Section Class', 'roofer' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter Section Class', 'roofer' ),
			]
		);

		$this->end_controls_section();


		$this->start_controls_section(
			'content_section',
			[
				'label' => __( 'Slider Block', 'roofer' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);



		$this->add_control(
		  'repeat', 
			[
				'type' => Controls_Manager::REPEATER,
				'seperator' => 'before',
				'default' => 
					[
						['block_title' => esc_html__('Projects Completed', 'roofer')],
					],
				'fields' => 

					[	

						[
							'name' => 'block_bgimg',
							'label' => esc_html__('Background image', 'rashid'),
							'type' => Controls_Manager::MEDIA,
							'default' => ['url' => Utils::get_placeholder_image_src(),],
						],

						'block_subtitle'=>
						[
							'name' => 'block_subtitle',
							'label' => esc_html__('Subtitle', 'rashid'),
							'type' => Controls_Manager::TEXTAREA,
							'default' => esc_html__('', 'rashid')
						],


						'block_title'=>
						[
							'name' => 'block_title',
							'label' => esc_html__('Title', 'rashid'),
							'type' => Controls_Manager::TEXTAREA,
							'default' => esc_html__('', 'rashid')
						],

						'block_text'=>
						[
							'name' => 'block_text',
							'label' => esc_html__('Text', 'rashid'),
							'type' => Controls_Manager::TEXTAREA,
							'default' => esc_html__('', 'rashid')
						],


						 'block_button'=>
						[
							'name' => 'block_button',
							'label'       => __( 'Button', 'rashid' ),
							'type'        => Controls_Manager::TEXT,
							'dynamic'     => [
								'active' => true,
							],
							'placeholder' => __( 'Enter your Button Title', 'rashid' ),
							'default' => esc_html__('Read More', 'rashid'),
						],

						'block_text2'=>
						[
							'name' => 'block_text2',
							'label' => esc_html__('Text', 'rashid'),
							'type' => Controls_Manager::TEXTAREA,
							'default' => esc_html__('', 'rashid')
						],

						'block_icons'=>
						[
							'name' => 'block_icons',
							'label' => esc_html__('Enter The icons', 'rashid'),
							'type' => Controls_Manager::ICONS,							
						],
		

							
					],

				'title_field' => '{{block_title}}',
			 ]
		);
		
		
		$this->end_controls_section();	
		
				
		
	}

	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	 
	protected function render() {
		$settings = $this->get_settings_for_display();
		$allowed_tags = wp_kses_allowed_html('post');
		?>
        	

	<?php
	  echo '
	 <script>
 jQuery(document).ready(function($)
 {

//put the js code under this line 

var $myCarousel = $("#minimal-bootstrap-carousel"),
$firstAnimatingElems = $myCarousel
.find(".carousel-item:first")
.find("[data-animation ^= "animated"]");

//Initialize carousel
$myCarousel.carousel();

//put the code above the line 

  });
</script>';


?>


	<div id="minimal-bootstrap-carousel" class="carousel slide carousel-fade  slider-home-one <?php echo esc_attr($settings['sec_class']);?>">
        <!-- Wrapper for slides -->
        <div class="carousel-inner">
			<?php foreach($settings['repeat'] as $key=>$item):?>	
				<div class="carousel-item slide-1" style="background-image: url(<?php echo wp_get_attachment_url($item['block_bgimg']['id']);?>);">
					<div class="carousel-caption">
						<div class="container">
							<div class="box valign-middle">
								<div class="content text-left">
									<div class="slider-content-style-two" data-animation="animated fadeInUp">
										<span class="tag-line"><?php echo wp_kses($item['block_subtitle'], $allowed_tags);?></span>
										<h2><?php echo wp_kses($item['block_title'], $allowed_tags);?></h2>
										<p><?php echo wp_kses($item['block_text'], $allowed_tags);?></p>
										<form action="#" class="cta-form">
											<select class="selectpicker">
												<option>Payroll services</option>
												<option>Payroll services</option>
												<option>Payroll services</option>
												<option>Payroll services</option>
												<option>Payroll services</option>
											</select>
											<div class="btn-box">
												<button type="submit" class="thm-btn"><?php echo wp_kses($item['block_button'], $allowed_tags);?></button>
												<div class="btn-tag-line"><?php echo wp_kses($item['block_text2'], $allowed_tags);?><i class="<?php echo str_replace("icon ", " ", esc_attr( $item['block_icons']['value']));?>"></i></div>
											</div>
										</form>
									</div>
								</div>
							</div>
						</div>
					</div>
				</div>
			<?php endforeach; ?>
        </div>
        <!-- Controls -->
        <a class="carousel-control-prev" href="#minimal-bootstrap-carousel" role="button" data-slide="prev">
            <i class="fa fa-arrow-left"></i>
            <span class="sr-only">Previous</span>
        </a>
        <a class="carousel-control-next" href="#minimal-bootstrap-carousel" role="button" data-slide="next">
            <i class="fa fa-arrow-right"></i>
            <span class="sr-only">Next</span>
        </a>
    </div>

             
		<?php 
	}

}