<?php

namespace ROOFERPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Solution_One extends Widget_Base {

	/**
	 * Get widget name. 
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'roofer_solution_one';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Solution One', 'roofer' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fa fa-briefcase';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'roofer' ];
	}
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'solution_one',
			[
				'label' => esc_html__( 'Solution One', 'roofer' ),
			]
		);

		$this->add_control(
			'style',
			[
				'label'   => esc_html__( 'Select Style', 'rashid' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'style1',
				'options' => array(
					'style1'   => esc_html__( 'Style One', 'rashid' ),
					'style2'   => esc_html__( 'Style Two', 'rashid' ),
				),
			]
		);

		$this->add_control(
			'sec_class',
			[
				'label'       => __( 'Section Class', 'roofer' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter Section Class', 'roofer' ),
			]
		);
		
		$this->end_controls_section();
		
		// New Tab#1

		$this->start_controls_section(
					'content_section',
					[
						'label' => __( 'Slider Block', 'roofer' ),
						'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
					]
				);

				$this->add_control(
				  'repeat', 
					[
						'type' => Controls_Manager::REPEATER,
						'seperator' => 'before',
						'default' => 
							[
								['block_title' => esc_html__('Projects Completed', 'roofer')],
							],
						'fields' => 

							[	

								'block_icons'=>	
								[
									'name' => 'block_icons',
									'label' => esc_html__('Enter The icons', 'rashid'),
									'type' => Controls_Manager::ICONS,
															
								],


									'block_title'=>	
								[
									'name' => 'block_title',
									'label' => esc_html__('Title', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],

								'block_subtitle'=>	
								[
									'name' => 'block_subtitle',
									'label' => esc_html__('Subtitle', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],


								'block_title2'=>	
								[
									'name' => 'block_title2',
									'label' => esc_html__('Title', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],

								'block_text'=>
								[
									'name' => 'block_text',
									'label' => esc_html__('Text', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],


									'block_btnlink'=>	
								[
									'name' => 'block_btnlink',
									'label' => __( 'Button Url', 'rashid' ),
									'type' => Controls_Manager::URL,
									'placeholder' => __( 'https://your-link.com', 'rashid' ),
									'show_external' => true,
									'default' => [
									  'url' => '',
									  'is_external' => true,
									  'nofollow' => true,
									],
								],


									 'block_button'=>	
								[
									'name' => 'block_button',
									'label'       => __( 'Button', 'rashid' ),
									'type'        => Controls_Manager::TEXT,
									'dynamic'     => [
										'active' => true,
									],
									'placeholder' => __( 'Enter your Button Title', 'rashid' ),
									'default' => esc_html__('Read More', 'rashid'),
								],

								'block_image'=>	
								[
									'name' => 'block_image',
									'label' => __( 'Image', 'rashid' ),
									'type' => Controls_Manager::MEDIA,
									'default' => ['url' => Utils::get_placeholder_image_src(),],
								  ],
								  
								  
								  'block_alt_text'=>	
						  
								  [
								  'name' => 'block_alt_text',
								  'label' => esc_html__('Image Text', 'rashid'),
								  'type' => Controls_Manager::TEXTAREA,
								  'default' => esc_html__('', 'rashid')
								  ],	

									
							],
						'title_field' => '{{block_title}}',
					 ]
			);
				
				
		$this->end_controls_section();	
					
		
		}

	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	 
	protected function render() {
		$settings = $this->get_settings_for_display();
		$allowed_tags = wp_kses_allowed_html('post');
		?>
        	

	<?php
	  echo '
	 <script>
 jQuery(document).ready(function($)
 {

//put the js code under this line 


//put the code above the line 

  });
</script>';


?>

	<?php  if ( 'style1' === $settings['style'] ) : ?>
	<section class="service-style-one solutions-page <?php echo esc_attr($settings['sec_class']);?>">
        <div class="container">
            <ul class="nav nav-tabs tab-title clearfix" role="tablist">
				<?php foreach($settings['repeat'] as $key=>$item):?>
                	<li class="nav-item">
						<a class="nav-link <?php if($key == 0) echo 'active';?>" id="#id-<?php echo esc_attr($key);?>" href="#id-<?php echo esc_attr($key);?>" role="tab" data-toggle="tab">
							<span class="icon-box">
								<i class="<?php echo str_replace("icon ", " ", esc_attr( $item['block_icons']['value']));?>"></i>
							</span>
							<h3><?php echo wp_kses($item['block_title'], $allowed_tags);?></h3>
						</a>
                	</li>
				<?php endforeach; ?>
            </ul>

            <!-- Tab panes -->
            <div class="tab-content">
				<?php foreach($settings['repeat'] as $key=>$item):?>
					<div role="tabpanel" class="tab-pane fade show <?php if($key == 1) echo 'active';?>" id="id-<?php echo esc_attr($key);?>">
						<div class="single-tab-content-two">
							<div class="row">
								<div class="col-lg-6">
									<div class="sec-title">
										<span><?php echo wp_kses($item['block_subtitle'], $allowed_tags);?></span>
										<h2><?php echo wp_kses($item['block_title2'], $allowed_tags);?></h2>
									</div><!-- /.sec-title -->
									<p><?php echo wp_kses($item['block_text'], $allowed_tags);?></p>
									<div class="row">
										<div class="col-xl-6 col-lg-12 col-md-6 col-sm-12 col-xs-12">
											<ul class="list-items">
												<li> <i class="fa fa-check-circle"></i> Time & Attendance </li>
												<li> <i class="fa fa-check-circle"></i> Schedule Exchange </li>
												<li> <i class="fa fa-check-circle"></i> Time-Off Requests </li>
												<li> <i class="fa fa-check-circle"></i> Time Clocks </li>
											</ul><!-- /.list-items -->
										</div><!-- /.col-lg-6 -->
										<div class="col-xl-6 col-lg-12 col-md-6 col-sm-12 col-xs-12">
											<ul class="list-items">
												<li> <i class="fa fa-check-circle"></i> Labor Allocation </li>
												<li> <i class="fa fa-check-circle"></i> Labor Management Reports </li>
												<li> <i class="fa fa-check-circle"></i> Enhanced ACA </li>
												<li> <i class="fa fa-check-circle"></i> Time and Labor Analytics </li>
											</ul><!-- /.list-items -->
										</div><!-- /.col-lg-6 -->
									</div><!-- /.row -->
									<a href="<?php echo esc_url($item['block_btnlink']['url']);?>" class="thm-btn"><?php echo wp_kses($item['block_button'], $allowed_tags);?></a>
								</div><!-- /.col-lg-6 -->
								<div class="col-lg-6">
									<?php if(wp_get_attachment_url($item['block_image']['id'])): ?>
										<img src="<?php echo wp_get_attachment_url($item['block_image']['id']);?>" alt="<?php echo wp_kses($item['block_alt_text'], $allowed_tags);?>">
										<?php else :?>
										<div class="noimage"></div>
									<?php endif;?>
								</div><!-- /.col-lg-6 -->
							</div><!-- /.row -->
							
						</div>
					</div>
				<?php endforeach; ?>
            </div>
        </div>
    </section>
	<?php endif ;?>	



	<?php  if ( 'style2' === $settings['style'] ) : ?>
		<section class="sec-pad solutions-tab-one <?php echo esc_attr($settings['sec_class']);?>">
			<div class="container">
				<ul class="nav nav-tabs tab-title clearfix" role="tablist">
					<?php foreach($settings['repeat'] as $key=>$item):?>
						<li class="nav-item">
							<a class="nav-link <?php if($key == 0) echo 'active';?>" id="#id-<?php echo esc_attr($key);?>" href="#id-<?php echo esc_attr($key);?>" role="tab" data-toggle="tab">
								<span class="icon-box">
									<i class="<?php echo str_replace("icon ", " ", esc_attr( $item['block_icons']['value']));?>"></i>
								</span>
								<h3><?php echo wp_kses($item['block_title'], $allowed_tags);?></h3>
							</a>
						</li>
					<?php endforeach; ?>
				</ul>
				<div class="tab-content">
				<?php foreach($settings['repeat'] as $key=>$item):?>
					<div role="tabpanel" class="tab-pane fade show <?php if($key == 1) echo 'active';?>" id="id-<?php echo esc_attr($key);?>">
						<div class="single-tab-content-two">
							<div class="row">
								<div class="col-lg-6">
									<div class="sec-title">
										<span><?php echo wp_kses($item['block_subtitle'], $allowed_tags);?></span>
										<h2><?php echo wp_kses($item['block_title2'], $allowed_tags);?></h2>
									</div><!-- /.sec-title -->
									<p><?php echo wp_kses($item['block_text'], $allowed_tags);?></p>
									<div class="row">
										<div class="col-xl-12 col-lg-12 col-md-12 col-sm-12 col-xs-12">
											<ul class="list-items">
												<li> <i class="fa fa-check-circle"></i> Use shift templates and schedule groups to create and edit schedules. </li>
												<li> <i class="fa fa-check-circle"></i> Set exception, rounding and deviation rules for your pay classes. </li>
												<li> <i class="fa fa-check-circle"></i> Implement a point system in line with company policies. </li>
												<li> <i class="fa fa-check-circle"></i> Employees can view their schedule, as well as approve it and move it to their online time sheet. </li>
												<li> <i class="fa fa-check-circle"></i> Monitor scheduling changes, daily exceptions other attendance activity.</li>
												<li> <i class="fa fa-check-circle"></i> Allocate shifts on a day-to-day basis.</li>
												<li> <i class="fa fa-check-circle"></i> Batch-assign shifts to multiple employees.</li>
												<li> <i class="fa fa-check-circle"></i> Assigned shifts automatically display on in Employee Self-Service.</li>
												<li> <i class="fa fa-check-circle"></i> Co-workers can swap shifts or issue requests for a shift to be picked up.</li>
											</ul><!-- /.list-items -->
										</div><!-- /.col-lg-6 -->                                    
									</div><!-- /.row -->
									<a href="<?php echo esc_url($item['block_btnlink']['url']);?>" class="thm-btn"><?php echo wp_kses($item['block_button'], $allowed_tags);?></a>
								</div><!-- /.col-lg-6 -->
								<div class="col-lg-6">
									<?php if(wp_get_attachment_url($item['block_image']['id'])): ?>
										<img src="<?php echo wp_get_attachment_url($item['block_image']['id']);?>" alt="<?php echo wp_kses($item['block_alt_text'], $allowed_tags);?>">
										<?php else :?>
										<div class="noimage"></div>
									<?php endif;?>
								</div><!-- /.col-lg-6 -->
							</div><!-- /.row -->
							
						</div>
					</div>
				<?php endforeach; ?>
            </div>
			</div>
    	</section>
	<?php endif ;?>	

             
		<?php 
	}

}