<?php

namespace ROOFERPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Testimonials_one extends Widget_Base {

	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'roofer_testimonials_one';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Testimonials One', 'roofer' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fa fa-briefcase';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'roofer' ];
	}
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'testimonials_one',
			[
				'label' => esc_html__( 'Testimonials One', 'roofer' ),
			]
		);

		$this->add_control(
			'sec_class',
			[
				'label'       => __( 'Section Class', 'roofer' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter Section Class', 'roofer' ),
			]
		);

		$this->add_control(
			'image',
				[
				  'label' => __( 'Image', 'rashid' ),
				  'type' => Controls_Manager::MEDIA,
				  'default' => ['url' => Utils::get_placeholder_image_src(),],
				]
		);	
		
		$this->add_control(
			'alt_text',
			[
				'label'       => __( 'Alt text', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Description', 'rashid' ),
			]
		);

		$this->add_control(
			'image2',
				[
				  'label' => __( 'Image', 'rashid' ),
				  'type' => Controls_Manager::MEDIA,
				  'default' => ['url' => Utils::get_placeholder_image_src(),],
				]
		);	
		
		$this->add_control(
			'alt_text2',
			[
				'label'       => __( 'Alt text', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Description', 'rashid' ),
			]
		);

		$this->add_control(
			'image3',
				[
				  'label' => __( 'Image', 'rashid' ),
				  'type' => Controls_Manager::MEDIA,
				  'default' => ['url' => Utils::get_placeholder_image_src(),],
				]
		);	
		
		$this->add_control(
			'alt_text3',
			[
				'label'       => __( 'Alt text', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Description', 'rashid' ),
			]
		);

		$this->add_control(
			'image4',
				[
				  'label' => __( 'Image', 'rashid' ),
				  'type' => Controls_Manager::MEDIA,
				  'default' => ['url' => Utils::get_placeholder_image_src(),],
				]
		);	
		
		$this->add_control(
			'alt_text4',
			[
				'label'       => __( 'Alt text', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Description', 'rashid' ),
			]
		);


		
		$this->end_controls_section();
		
		// New Tab#1

		$this->start_controls_section(
					'content_section',
					[
						'label' => __( 'Slider Block', 'roofer' ),
						'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
					]
				);
				$this->add_control(
				  'repeat', 
					[
						'type' => Controls_Manager::REPEATER,
						'seperator' => 'before',
						'default' => 
							[
								['block_title' => esc_html__('Projects Completed', 'roofer')],
							],
						'fields' => 
							[	

								'block_bgimg'=>
								[
									'name' => 'block_bgimg',
									'label' => esc_html__('Background image', 'rashid'),
									'type' => Controls_Manager::MEDIA,
									'default' => ['url' => Utils::get_placeholder_image_src(),],
								],

								'block_icons'=>
								[
									'name' => 'block_icons',
									'label' => esc_html__('Enter The icons', 'rashid'),
									'type' => Controls_Manager::ICONS,							
								],


								'block_text'=>
								[
									'name' => 'block_text',
									'label' => esc_html__('Text', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],


								'block_title'=>
								[
									'name' => 'block_title',
									'label' => esc_html__('Title', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],

								'block_text1'=>
								[
									'name' => 'block_text1',
									'label' => esc_html__('Text', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],

								'block_text2'=>
								[
									'name' => 'block_text2',
									'label' => esc_html__('Text', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],

								'block_text3'=>
								[
									'name' => 'block_text3',
									'label' => esc_html__('Text', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],

								
								'block_btnlink'=>
								[
									'name' => 'block_btnlink',
									'label' => __( 'Button Url', 'rashid' ),
									'type' => Controls_Manager::URL,
									'placeholder' => __( 'https://your-link.com', 'rashid' ),
									'show_external' => true,
									'default' => [
									  'url' => '',
									  'is_external' => true,
									  'nofollow' => true,
									],
								],

								'block_icons2'=>
								[
									'name' => 'block_icons2',
									'label' => esc_html__('Enter The icons', 'rashid'),
									'type' => Controls_Manager::ICONS,							
								],


								'block_text4'=>
								[
									'name' => 'block_text4',
									'label' => esc_html__('Text', 'rashid'),
									'type' => Controls_Manager::TEXTAREA,
									'default' => esc_html__('', 'rashid')
								],

								'block_icons3'=>
								[
									'name' => 'block_icons3',
									'label' => esc_html__('Enter The icons', 'rashid'),
									'type' => Controls_Manager::ICONS,							
								],	

									
							],
						'title_field' => '{{block_title}}',
					 ]
			);
				
				
		$this->end_controls_section();	
					
		
		}

	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	 
	 protected function render() {
		$settings = $this->get_settings_for_display();
		$allowed_tags = wp_kses_allowed_html('post');
		?>
        	

	<?php
	  echo '
	 <script>
 jQuery(document).ready(function($)
 {

//put the js code under this line 
	

if ($(".testimonials-style-two .slider").length) {
	$(".testimonials-style-two .slider").bxSlider({
		adaptiveHeight: true,
		auto: false,
		controls: false,
		pause: 5000,
		speed: 1000,
		mode: "fade",
		pagerCustom: "#testi-pager"
	});
}


//put the code above the line 

  });
</script>';


?>

	<section class="testimonials-style-two <?php echo esc_attr($settings['sec_class']);?>">
        <!--Slider-->
        <ul class="slider">
		<?php foreach($settings['repeat'] as $key=>$item):?>
				<li class="slide-item">
					<?php if(wp_get_attachment_url($item['block_bgimg']['id'])): ?>
						<div class="single-testimonial-two sec-pad" style="background-image: url(<?php echo wp_get_attachment_url($item['block_bgimg']['id']);?>);">
						<div class="container">
								<div class="row">
									<div class="col-lg-7">
										<div class="text-box">
											<i class="<?php echo str_replace("icon ", " ", esc_attr( $item['block_icons']['value']));?>"></i>
											<p><?php echo wp_kses($item['block_text'], $allowed_tags);?></p>
											<h3><?php echo wp_kses($item['block_title'], $allowed_tags);?></h3>
											<ul class="list-items">
												<li><?php echo wp_kses($item['block_text1'], $allowed_tags);?></li>
												<li><?php echo wp_kses($item['block_text2'], $allowed_tags);?></li>
												<li><?php echo wp_kses($item['block_text3'], $allowed_tags);?></li>
											</ul>
										</div>
									</div>
									<div class="col-lg-5 d-flex">
										<div class="video-popup-box my-auto text-center">
											<a href="<?php echo esc_url($item['block_btnlink']['url']);?>" class="video-popup">
												<i class="<?php echo str_replace("icon ", " ", esc_attr( $item['block_icons2']['value']));?>"></i>
												<span class="btn-tag-line"><?php echo wp_kses($item['block_text4'], $allowed_tags);?> <i class="<?php echo str_replace("icon ", " ", esc_attr( $item['block_icons3']['value']));?>"></i></span>
											</a>
										</div>
									</div>
								</div>
							</div>
						</div>
						<?php else :?>	
						<div class="noimage"></div>
					<?php endif;?>
				</li>
				<?php endforeach; ?>
        </ul>
        <div class="container">
            <!--Custom-Pager-->
            <div class="testi-pager row" id="testi-pager">
                <div class="col-lg-3 col-md-3 col-sm-3 col-xs-3">
                    <a href="#" class="pager-item active" data-slide-index="0">
                        <div class="testi-thumb">
							<?php  if ( esc_url($settings['image']['id']) ) : ?>   
								<img src="<?php echo wp_get_attachment_url($settings['image']['id']);?>" alt="<?php echo esc_attr($settings['alt_text']);?>"/>
								<?php else :?>
								<div class="noimage"></div>
							<?php endif;?>
						</div>                
                    </a>
                </div>
                <div class="col-lg-3 col-md-3 col-sm-3 col-xs-3">
                    <a href="#" class="pager-item" data-slide-index="1">
						<div class="testi-thumb">
							<?php  if ( esc_url($settings['image2']['id']) ) : ?>   
								<img src="<?php echo wp_get_attachment_url($settings['image2']['id']);?>" alt="<?php echo esc_attr($settings['alt_text2']);?>"/>
								<?php else :?>
								<div class="noimage"></div>
							<?php endif;?>
						</div>                 
                    </a>
                </div>
                <div class="col-lg-3 col-md-3 col-sm-3 col-xs-3">
                    <a href="#" class="pager-item" data-slide-index="2">
						<div class="testi-thumb">
							<?php  if ( esc_url($settings['image3']['id']) ) : ?>   
								<img src="<?php echo wp_get_attachment_url($settings['image3']['id']);?>" alt="<?php echo esc_attr($settings['alt_text3']);?>"/>
								<?php else :?>
								<div class="noimage"></div>
							<?php endif;?>
						</div>                 
                    </a>
                </div>
                <div class="col-lg-3 col-md-3 col-sm-3 col-xs-3">
                    <a href="#" class="pager-item" data-slide-index="3">
						<div class="testi-thumb">
							<?php  if ( esc_url($settings['image4']['id']) ) : ?>   
								<img src="<?php echo wp_get_attachment_url($settings['image4']['id']);?>" alt="<?php echo esc_attr($settings['alt_text4']);?>"/>
								<?php else :?>
								<div class="noimage"></div>
							<?php endif;?>
						</div>                 
                    </a>
                </div>
            </div>
        </div>
    </section>
             
		<?php 
	}

}