<?php

namespace ROOFERPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;
use Elementor\Utils;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Blog_Grid extends Widget_Base {

	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'roofer_blog_grid';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Blog Grid', 'roofer' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-post';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'roofer' ];
	}
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'blog_grid',
			[
				'label' => esc_html__( 'Blog Grid', 'roofer' ),
			]
		);

		$this->add_control(
			'style',
			[
				'label'   => esc_html__( 'Select Style', 'rashid' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'style1',
				'options' => array(
					'style1'   => esc_html__( 'Style One', 'rashid' ),
					'style2'   => esc_html__( 'Style Two', 'rashid' ),
					'style3'   => esc_html__( 'Style Three', 'rashid' ),
					'style4'   => esc_html__( 'Style Four', 'rashid' ),
				),
			]
		);

		$this->add_control(
            'thumb', 
				[
					'label'   => esc_html__( 'Choose Post Image', 'constech' ),
					'label_block' => true,
					'type'    => Controls_Manager::SELECT,
					'default' => 'style1',
					'options' => array(
						'style1' => esc_html__( 'Meta Box Image', 'constech' ),
						'style2' => esc_html__( 'Dafult Thumbnail', 'constech' ),
					),
				]
		);
		
		
		$this->add_control(
			'bttn',
			[
				'label'       => __( 'Button', 'roofer' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => esc_html__( 'Enter your Button Title', 'roofer' ),
				'default' => esc_html__('Read More', 'roofer'),
			]
		);	
		$this->add_control(
			'column',
			[
				'label'   => esc_html__( 'Column', 'roofer' ),
				'type'    => Controls_Manager::SELECT,
				'default' => '3',
				'options' => array(
					'12'   => esc_html__( 'One Column', 'roofer' ),
					'6'   => esc_html__( 'Two Column', 'roofer' ),
					'4'   => esc_html__( 'Three Column', 'roofer' ),
					'3'   => esc_html__( 'Four Column', 'roofer' ),
					'2'   => esc_html__( 'Six Column', 'roofer' ),
				),
			]
		);
		$this->add_control(
			'sec_class',
			[
				'label'       => __( 'Section Class', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter Section Class', 'rashid' ),
			]
		);
		
		
		$this->end_controls_section();
	
		$this->start_controls_section(
				'content_section',
				[
					'label' => __( 'Blog Block', 'roofer' ),
					'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
				]
			);
			
		
		$this->add_control(
			'text_limit',
			[
				'label'   => esc_html__( 'Text Limit', 'roofer' ),
				'type'    => Controls_Manager::NUMBER,
				'default' => 15,
				'min'     => 1,
				'max'     => 100,
				'step'    => 1,
			]
		);
		$this->add_control(
			'query_number',
			[
				'label'   => esc_html__( 'Number of post', 'roofer' ),
				'type'    => Controls_Manager::NUMBER,
				'default' => 3,
				'min'     => 1,
				'max'     => 100,
				'step'    => 1,
			]
		);
		$this->add_control(
			'query_orderby',
			[
				'label'   => esc_html__( 'Order By', 'roofer' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'date',
				'options' => array(
					'date'       => esc_html__( 'Date', 'roofer' ),
					'title'      => esc_html__( 'Title', 'roofer' ),
					'menu_order' => esc_html__( 'Menu Order', 'roofer' ),
					'rand'       => esc_html__( 'Random', 'roofer' ),
				),
			]
		);
		$this->add_control(
			'query_order',
			[
				'label'   => esc_html__( 'Order', 'roofer' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'DESC',
				'options' => array(
					'DESc' => esc_html__( 'DESC', 'roofer' ),
					'ASC'  => esc_html__( 'ASC', 'roofer' ),
				),
			]
		);
		$this->add_control(
			'query_exclude',
			[
				'label'       => esc_html__( 'Exclude', 'roofer' ),
				'type'        => Controls_Manager::TEXT,
				'description' => esc_html__( 'Exclude posts, pages, etc. by ID with comma separated.', 'roofer' ),
			]
		);
		$this->add_control(
            'query_category', 
				[
				  'type' => Controls_Manager::SELECT,
				  'label' => esc_html__('Category', 'roofer'),
				  'options' => get_blog_categories()
				]
		);

		$this->add_control(
			'bttn',
			[
				'label'       => __( 'Button', 'rashid' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => esc_html__( 'Enter your Button Title', 'rashid' ),
				'default' => esc_html__('Read More', 'rashid'),
			]
		);	

		$this->add_control(
			'text',
			[
				'label'       => __( 'Description Text', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Description', 'rashid' ),
			]
		);
		
		$this->end_controls_section();

	}

	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
        
        $paged = roofer_set($_POST, 'paged') ? esc_attr($_POST['paged']) : 1;

		$this->add_render_attribute( 'wrapper', 'class', 'templatepath-roofer' );
		$args = array(
			'post_type'      => 'post',
			'posts_per_page' => roofer_set( $settings, 'query_number' ),
			'orderby'        => roofer_set( $settings, 'query_orderby' ),
			'order'          => roofer_set( $settings, 'query_order' ),
			'paged'         => $paged
		);
		if ( roofer_set( $settings, 'query_exclude' ) ) {
			$settings['query_exclude'] = explode( ',', $settings['query_exclude'] );
			$args['post__not_in']      = roofer_set( $settings, 'query_exclude' );
		}
		if( roofer_set( $settings, 'query_category' ) ) $args['category_name'] = roofer_set( $settings, 'query_category' );
		$query = new \WP_Query( $args );

		if ( $query->have_posts() ) 
		{ ?>

	<?php  if ( 'style1' === $settings['style'] ) : ?>
	<section class="blog__section p_relative <?php echo esc_attr($settings['sec_class']);?>">
        <div class="blog__content">
		<div class="auto_container">	
			<div class="row">
				<?php while ( $query->have_posts() ) : $query->the_post();
					$meta_image = get_post_meta( get_the_id(), 'meta_image', true );
					?>
				<div class="col-lg-<?php echo esc_attr($settings['column'], true );?> col-md-6 col-sm-12">
					<div class="news__block__one wow fadeInUp animated" data-wow-delay="00ms" data-wow-duration="1500m">
						<div class="inner__box">
							<div class="image__box">
								<figure class="image">
									<a href="<?php echo esc_url( the_permalink( get_the_id() ) );?>">
										<?php  if ( 'style1' === $settings['thumb'] ) : ?>
										<img src="<?php echo wp_get_attachment_url($meta_image['id']);?>" alt="" />
										<?php endif; ?> 
										<?php  if ( 'style2' === $settings['thumb'] ) : ?>      
										<?php  the_post_thumbnail();    ?>
										<?php endif; ?> 
									</a>
								</figure>
							</div>
							<div class="lower__content">
								<div class="image_layer shape-06" style="background-image:url(<?php echo esc_url(get_template_directory_uri().'/assets/images/shape/shape-06.png');?>)"></div>
								<div class="news__date" style="background-image:url(<?php echo esc_url(get_template_directory_uri().'/assets/images/shape/shape-05.png');?>)">
									<a href="<?php echo get_day_link( get_the_time( 'Y' ), get_the_time( 'm' ), get_the_time( 'd' ) ); ?>"><?php echo get_the_date('d'); ?> <span><?php echo get_the_date('M'); ?></span> </a>
								</div>
								<div class="news__title">
									<h4><a href="<?php echo esc_url( the_permalink( get_the_id() ) );?>"><?php the_title(); ?></a></h4>
								</div>
								<div class="author__info">
									<ul>
										<li> 
											<a href="<?php echo esc_url(get_author_posts_url( get_the_author_meta('ID') )); ?>"><span class="icon-icon-22"></span>by <?php the_author(); ?></a> <span><?php comments_number(); ?></span>
										</li>
									</ul>
								</div>
								<div class="news__text">
									<p><?php echo roofer_trim(get_the_content(), $settings['text_limit']); ?></p>
								</div>
								<div class="more__btn">
									<a href="<?php echo esc_url( the_permalink( get_the_id() ) );?>"><?php esc_html_e('Read More', 'roofer'); ?> <span class="icon-53"></span> <span class="icon-52"></span></a>
								</div>
							</div>
						</div>
					</div>
				</div> 
				<?php endwhile; ?>   
            </div>
		</div>
        </div>
    </section>
	<?php endif ;?>	

	<?php  if ( 'style2' === $settings['style'] ) : ?>
	<!-- service-section-two -->
	<section class="service__page p_relative see__pad <?php echo esc_attr($settings['sec_class']);?>">
		<div class="service__content__two">
			<div class="auto_container">
				<div class="row">
				<?php while ( $query->have_posts() ) : $query->the_post();
				$meta_image = get_post_meta( get_the_id(), 'meta_image', true );
				?>
					<div class="col-lg-<?php echo esc_attr($settings['column'], true );?> col-md-6 col-sm-12">
						<div class="service__block__one wow fadeInUp animated" data-wow-delay="00ms" data-wow-duration="1500m">
							<div class="inner__box">
								<div class="image__box">
									<figure class="image">
										<a href="<?php echo esc_url( the_permalink( get_the_id() ) );?>">
											<?php  if ( 'style1' === $settings['thumb'] ) : ?>
											<img src="<?php echo wp_get_attachment_url($meta_image['id']);?>" alt="" />
											<?php endif; ?> 
											<?php  if ( 'style2' === $settings['thumb'] ) : ?>      
											<?php  the_post_thumbnail();    ?>
											<?php endif; ?> 
										</a>
									</figure>
								</div>
								<div class="lower__content">
									<div class="image_layer shape-06" style="background-image:url(<?php echo esc_url(get_template_directory_uri().'/assets/images/shape/shape-06.png');?>)"></div>
									<div class="service__icon">
										<div class="image_layer_one shape-34" style="background-image:url(<?php echo esc_url(get_template_directory_uri().'/assets/images/shape/shape-34.png');?>)"></div>
										<div class="image_layer_two shape-35" style="background-image:url(<?php echo esc_url(get_template_directory_uri().'/assets/images/shape/shape-35.png');?>)"></div>
										<div class="icon">
											<span class="icon-27"></span>
										</div>
									</div>
									<div class="service__title">
										<h4> <a href="<?php echo esc_url( the_permalink( get_the_id() ) );?>"><?php the_title(); ?></a></h4>
									</div>
									<div class="service__text">
										<p><?php echo roofer_trim(get_the_content(), $settings['text_limit']); ?></p>
									</div>
									<div class="more__btn">
										<a href="<?php echo esc_url( the_permalink( get_the_id() ) );?>"><?php esc_html_e('Read More', 'roofer'); ?> <span class="icon-53"></span> <span class="icon-52"></span></a>
									</div>
								</div>
							</div>
						</div>
					</div>
					<?php endwhile; ?> 
				</div>
			</div>
		</div>
	</section>
	<!-- service-section-twoend -->
	<?php endif ;?>
	
	<?php  if ( 'style3' === $settings['style'] ) : ?>
	<section class="blog__section blog__grid p_relative see__pad <?php echo esc_attr($settings['sec_class']);?>">
		<div class="blog__content">
			<div class="auto_container">
				<div class="row">
					<?php while ( $query->have_posts() ) : $query->the_post();
						$meta_image = get_post_meta( get_the_id(), 'meta_image', true );
						?>
						<div class="col-lg-<?php echo esc_attr($settings['column'], true );?> col-md-6 col-sm-12">
							<div class="news__block__one wow fadeInUp animated" data-wow-delay="00ms" data-wow-duration="1500m">
								<div class="inner__box">
									<div class="image__box">
										<figure class="image">
											<a href="<?php echo esc_url( the_permalink( get_the_id() ) );?>">
												<?php  if ( 'style1' === $settings['thumb'] ) : ?>
												<img src="<?php echo wp_get_attachment_url($meta_image['id']);?>" alt="" />
												<?php endif; ?> 
												<?php  if ( 'style2' === $settings['thumb'] ) : ?>      
												<?php  the_post_thumbnail();    ?>
												<?php endif; ?> 
											</a>
										</figure>
									</div>
									<div class="lower__content">
										<div class="image_layer shape-06" style="background-image:url(<?php echo esc_url(get_template_directory_uri().'/assets/images/shape/shape-06.png');?>)"></div>
										<div class="news__date" style="background-image:url(<?php echo esc_url(get_template_directory_uri().'/assets/images/shape/shape-05.png');?>)">
											<a href="<?php echo get_day_link( get_the_time( 'Y' ), get_the_time( 'm' ), get_the_time( 'd' ) ); ?>"><?php echo get_the_date('d'); ?> <span><?php echo get_the_date('M'); ?></span> </a>
										</div>
										<div class="news__title">
											<h4><a href="<?php echo esc_url( the_permalink( get_the_id() ) );?>"><?php the_title(); ?></a></h4>
										</div>
										<div class="author__info">
											<ul>
												<li> 
													<a href="<?php echo esc_url(get_author_posts_url( get_the_author_meta('ID') )); ?>"><span class="icon-icon-22"></span>by <?php the_author(); ?></a> <span><?php comments_number(); ?></span>
												</li>
											</ul>
										</div>
										<div class="news__text">
											<p><?php echo roofer_trim(get_the_content(), $settings['text_limit']); ?></p>
										</div>
										<div class="more__btn">
											<a href="<?php echo esc_url( the_permalink( get_the_id() ) );?>"><?php esc_html_e('Read More', 'roofer'); ?> <span class="icon-53"></span> <span class="icon-52"></span></a>
										</div>
									</div>
								</div>
							</div>
						</div> 
					<?php endwhile; ?>  
				</div>
				<div class="col-xl-12 mt-30">
					<ul class="styled-pagination text-center clearfix">
						<?php echo $settings['text'];?>
					</ul>
				</div>
			</div>
		</div>
	</section>
	<?php endif ;?>

        <?php }
		wp_reset_postdata();
	}

}