<?php

namespace ROOFERPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class News_Letter_Form extends Widget_Base {

	/**
	 * Get widget name. 
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'roofer_news_letter_form';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'News Letter Form', 'roofer' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fa fa-briefcase';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'roofer' ];
	}
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'news_letter_form',
			[
				'label' => esc_html__( 'News Letter Form', 'roofer' ),
			]
		);

		$this->add_control(
			'style',
			[
				'label'   => esc_html__( 'Select Style', 'rashid' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'style1',
				'options' => array(
					'style1'   => esc_html__( 'Style One', 'rashid' ),
					'style2'   => esc_html__( 'Style Two', 'rashid' ),
					'style3'   => esc_html__( 'Style Three', 'rashid' ),
				),
			]
		);

		$this->add_control(
			'sec_class',
			[
				'label'       => __( 'Section Class', 'roofer' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter Section Class', 'roofer' ),
			]
		);

		$this->add_control(
			'title',
			[
				'label'       => __( 'Title', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your title', 'rashid' ),
			]
		);

		$this->add_control(
			'contact_form',
			[
				'label'       => __( 'Contact Form 7 Url', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Contact Form 7 Url', 'rashid' ),
				'default'     => __( '', 'rashid' ),
			]
		);

		$this->add_control(
			'bgimg',
			[
				'label' => esc_html__('Background image', 'rashid'),
				'type' => Controls_Manager::MEDIA,
				'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
		);

		$this->add_control(
			'image',
				[
				  'label' => __( 'Image', 'rashid' ),
				  'type' => Controls_Manager::MEDIA,
				  'default' => ['url' => Utils::get_placeholder_image_src(),],
				]
		);	
		
		$this->add_control(
			'alt_text',
			[
				'label'       => __( 'Alt text', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Description', 'rashid' ),
			]
		);

		$this->add_control(
			'icons',
				[
					'label' => esc_html__('Enter The icons', 'rashid'),
					'type' => Controls_Manager::ICONS,
				]
		);

		$this->add_control(
			'btnlink',
			[
			  'label' => __( 'Button Url', 'rashid' ),
			  'type' => Controls_Manager::URL,
			  'placeholder' => __( 'https://your-link.com', 'rashid' ),
			  'show_external' => true,
			  'default' => [
				'url' => '',
				'is_external' => true,
				'nofollow' => true,
			  ],
			
		   ]
		);

		$this->add_control(
			'text',
			[
				'label'       => __( 'Description Text', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Description', 'rashid' ),
			]
		);

		$this->add_control(
			'text2',
			[
				'label'       => __( 'Description Text', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Description', 'rashid' ),
			]
		);


		$this->end_controls_section();

		
	}

	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	 
	protected function render() {
		$settings = $this->get_settings_for_display();
		$allowed_tags = wp_kses_allowed_html('post');
		?>
        	

<?php
	  echo '
	 <script>
 jQuery(document).ready(function($)
 {

//put the js code under this line 

//put the code above the line 

  });
</script>';


?>


<?php  if ( 'style1' === $settings['style'] ) : ?>
<section class="news_letter <?php echo esc_attr($settings['sec_class']);?>">
	<div class="auto_container">
		<div class="news_letter_content">
			<div class="row">
				<div class="col-xl-6 col-lg-12">
					<div class="news_letter_left p_relative">
						<h3><?php echo $settings['title'];?></h3>
						<div class="form-inner p_relative">
							<?php echo do_shortcode( $settings['contact_form'] );?>
						</div>
					</div>
				</div>
				<div class="col-xl-6 col-lg-12 ps-xl-0">
					<div class="news_letter_right p_relative">
						<?php  if ( esc_url($settings['bgimg']['id']) ) : ?>
						<div class="image_layer shape_01" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg']['id']);?>);"></div>
						<?php else :?>	
						<div class="noimage"></div>
						<?php endif;?>

						<div class="news_letter_image">
							<figure class="image">
							<?php  if ( esc_url($settings['image']['id']) ) : ?>   
							<img src="<?php echo wp_get_attachment_url($settings['image']['id']);?>" alt="<?php echo esc_attr($settings['alt_text']);?>"/>
							<?php else :?>
							<div class="noimage"></div>
							<?php endif;?>
							</figure>
						</div>
					</div>
				</div>
			</div>
		</div>
	</div>
</section>
<?php endif ;?>	


<?php  if ( 'style2' === $settings['style'] ) : ?>
<section class="news_letter two">
		<div class="auto_container">
			<div class="news_letter_content" style="background-image:url(<?php echo wp_get_attachment_url($settings['bgimg']['id']);?>) ;">
				<div class="news_letter_left p_relative">
					<h3><?php echo $settings['title'];?></h3>
					<div class="form-inner p_relative">
						<?php echo do_shortcode( $settings['contact_form'] );?>
					</div>
				</div>
			</div>
		</div>
	</section>
<?php endif ;?>	


<!-- news-letter -->
<?php  if ( 'style3' === $settings['style'] ) : ?>
<section class="news_letter three see__pad">
	<div class="auto_container">
		<div class="news_letter_content">
			<div class="row">
				<div class="col-xl-6 col-lg-12">
					<div class="help__left">
						<div class="help__one">
							<span class="<?php echo str_replace("icon ", "", esc_attr( $settings['icons']['value']));?>"></span>
						</div>
						<div class="help__two">
							<h2><?php echo $settings['title'];?></h2>  
							<span><?php echo $settings['text'];?> <a href="<?php echo esc_url($settings['btnlink']['url']);?>"><?php echo $settings['text2'];?></a></span>
						</div>
					</div>
				</div>
				<div class="col-xl-6 col-lg-12 pl-40">
					<div class="news_letter_right p_relative">
						<div class="image_layer shape_01" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg']['id']);?>);"> </div>
						<div class="news_letter_image">
							<figure class="image">
								<?php  if ( esc_url($settings['image']['id']) ) : ?>   
								<img src="<?php echo wp_get_attachment_url($settings['image']['id']);?>" alt="<?php echo esc_attr($settings['alt_text']);?>"/>
								<?php else :?>
								<div class="noimage"></div>
								<?php endif;?>
							</figure>
						</div>
					</div>
				</div>
			</div>
		</div>
	</div>
</section>
<?php endif ;?>	
<!-- news-letter-end -->


		<?php 
	}

}