<?php

namespace ROOFERPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Portfolio_Slider extends Widget_Base {

	/**
	 * Get widget name. 
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'roofer_portfolio_slider';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Portfolio Slider', 'roofer' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fa fa-briefcase';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'roofer' ];
	}
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'portfolio_slider',
			[
				'label' => esc_html__( 'Portfolio Slider', 'roofer' ),
			]
		);

		$this->add_control(
			'style',
			[
				'label'   => esc_html__( 'Select Style', 'rashid' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'style1',
				'options' => array(
					'style1'   => esc_html__( 'Style One', 'rashid' ),
					'style2'   => esc_html__( 'Style Two', 'rashid' ),
				),
			]
		);

		$this->add_control(
			'sec_class',
			[
				'label'       => __( 'Section Class', 'roofer' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter Section Class', 'roofer' ),
			]
		);

		$this->end_controls_section();


		$this->start_controls_section(
			'content_section',
			[
				'label' => __( 'Slider Block', 'roofer' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
		  'repeat', 
			[
				'type' => Controls_Manager::REPEATER,
				'seperator' => 'before',
				'default' => 
					[
						['block_title' => esc_html__('Projects Completed', 'roofer')],
					],
				'fields' => 

					[	

						'block_title'=>
						[
							'name' => 'block_title',
							'label' => esc_html__('Title', 'rashid'),
							'type' => Controls_Manager::TEXTAREA,
							'default' => esc_html__('', 'rashid')
						],

						'block_subtitle'=>
						[
							'name' => 'block_subtitle',
							'label' => esc_html__('Sub Title', 'rashid'),
							'type' => Controls_Manager::TEXTAREA,
							'default' => esc_html__('', 'rashid')
						],

						'block_image'=>

						[
							'name' => 'block_image',
							'label' => __( 'Image', 'rashid' ),
							'type' => Controls_Manager::MEDIA,
							'default' => ['url' => Utils::get_placeholder_image_src(),],
						  ],
						  
						  'block_alt_text'=>

						  [
						  'name' => 'block_alt_text',
						  'label' => esc_html__('Image Text', 'rashid'),
						  'type' => Controls_Manager::TEXTAREA,
						  'default' => esc_html__('', 'rashid')
						  ],	

						  'block_btnlink'=>

						  [
							'name' => 'block_btnlink',
							'label' => __( 'Button Url', 'rashid' ),
							'type' => Controls_Manager::URL,
							'placeholder' => __( 'https://your-link.com', 'rashid' ),
							'show_external' => true,
							'default' => [
							  'url' => '',
							  'is_external' => true,
							  'nofollow' => true,
							],
						 ],


					],

				'title_field' => '{{block_title}}',
			 ]
		);
		
		
		$this->end_controls_section();	
		
				
		
	}

	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	 
	protected function render() {
		$settings = $this->get_settings_for_display();
		$allowed_tags = wp_kses_allowed_html('post');
		?>
        	

<?php
	  echo '
	 <script>
 jQuery(document).ready(function($)
 {

//put the js code under this line 

// portfolio-carousel
	if ($(".portfolio-carousel").length) {
        $(".portfolio-carousel").owlCarousel({
            loop:true,
			margin:24,
			nav:true,
			smartSpeed: 1000,
			autoplay: 6000,
            responsive:{
                0:{
                    items:1
                },
                600:{
                    items:2,
                },
                800:{
                    items:3,
                },
                1024:{
                    items:3,
                },
                1200:{
                    items:4
                }
            }
        });
    }

//put the code above the line 

  });
</script>';


?>


<?php  if ( 'style1' === $settings['style'] ) : ?>
<section class="portfolio p_relative <?php echo esc_attr($settings['sec_class']);?>">
	<div class="portfolio-carousel owl-carousel owl-theme owl-dots-none nav-style-one ">
	<?php foreach($settings['repeat'] as $item):?>
		<div class="portfolio__block__one">
			<div class="inner-box">
				<figure class="image-box">
					<?php if(wp_get_attachment_url($item['block_image']['id'])): ?>
					<img src="<?php echo wp_get_attachment_url($item['block_image']['id']);?>" alt="<?php echo wp_kses($item['block_alt_text'], $allowed_tags);?>">
					<?php else :?>
					<div class="noimage"></div>
					<?php endif;?>
				</figure>
				<div class="lower__content">
					<div class="view-btn"><a href="<?php echo wp_get_attachment_url($item['block_image']['id']);?>" class="lightbox-image" data-fancybox="gallery"><span class="icon-18"></span></a></div>
					<div class="portfolio__block">
						<span><?php echo wp_kses($item['block_subtitle'], $allowed_tags);?></span>
						<h4><a href="<?php echo esc_url($item['block_btnlink']['url']);?>"><?php echo wp_kses($item['block_title'], $allowed_tags);?></a></h4>
					</div>
				</div>
			</div>
		</div>
	<?php endforeach; ?>
	</div>
</section>
<?php endif ;?>	    


<?php  if ( 'style2' === $settings['style'] ) : ?>
	<section class="portfolio two p_relative <?php echo esc_attr($settings['sec_class']);?>">
            <div class="portfolio-carousel owl-carousel owl-theme owl-dots-none nav-style-one ">
			<?php foreach($settings['repeat'] as $item):?>
                <div class="portfolio__block__one">
                    <div class="inner-box">
                        <figure class="image-box">
						<?php if(wp_get_attachment_url($item['block_image']['id'])): ?>
						<img src="<?php echo wp_get_attachment_url($item['block_image']['id']);?>" alt="<?php echo wp_kses($item['block_alt_text'], $allowed_tags);?>">
						<?php else :?>
						<div class="noimage"></div>
						<?php endif;?>
                        </figure>
                        <div class="lower__content">
                            <div class="view-btn"><a href="<?php echo wp_get_attachment_url($item['block_image']['id']);?>" class="lightbox-image" data-fancybox="gallery"><span class="icon-18"></span></a></div>
                            <div class="portfolio__block">
                                <span><?php echo wp_kses($item['block_subtitle'], $allowed_tags);?></span>
                                <h4><a href="<?php echo esc_url($item['block_btnlink']['url']);?>"><?php echo wp_kses($item['block_title'], $allowed_tags);?></a></h4>
                            </div>
                        </div>
                    </div>
                </div>
			<?php endforeach; ?>
            </div>
        </section>
<?php endif ;?>	


		<?php 
	}

}