<?php

namespace ROOFERPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Portfolios extends Widget_Base {

	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'roofer_portfolios';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Portfolios', 'roofer' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fa fa-briefcase';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'roofer' ];
	}
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'portfolios',
			[
				'label' => esc_html__( 'portfolios', 'roofer' ),
			]
		);

		$this->add_control(
            'style', 
				[
					'label'   => esc_html__( 'Choose Different Style', 'cretox' ),
					'label_block' => true,
					'type'    => Controls_Manager::SELECT,
					'default' => 'style1',
					'options' => array(
						'style1' => esc_html__( 'Choose Style 1', 'cretox' ),
						'style2' => esc_html__( 'Choose Style 2', 'cretox' ),
						'style3' => esc_html__( 'Choose Style 3', 'cretox' ),
					),
				]
		);

		$this->add_control(
			'subtitle',
			[
				'label'       => __( 'Sub Title', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Sub title', 'rashid' ),
			]
		);
		$this->add_control(
			'title',
			[
				'label'       => __( 'Title', 'elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your title', 'elementor' ),
				
			]
		);
		$this->add_control(
			'bttn',
			[
				'label'       => __( 'Button', 'rashid' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Button Title', 'rashid' ),
			]
		);
		$this->add_control(
			'btnlink',
			[
			  'label' => __( 'Button Url', 'rashid' ),
			  'type' => Controls_Manager::URL,
			  'placeholder' => __( 'https://your-link.com', 'rashid' ),
			  'show_external' => true,
			  'default' => [
				'url' => '',
				'is_external' => true,
				'nofollow' => true,
			  ],
			
		   ]
		);
		$this->add_control(
			'column',
			[
				'label'   => esc_html__( 'Column', 'rashid' ),
				'type'    => Controls_Manager::SELECT,
				'default' => '3',
				'options' => array(
					'12'   => esc_html__( 'One Column', 'rashid' ),
					'6'   => esc_html__( 'Two Column', 'rashid' ),
					'4'   => esc_html__( 'Three Column', 'rashid' ),
					'3'   => esc_html__( 'Four Column', 'rashid' ),
					'2'   => esc_html__( 'Six Column', 'rashid' ),
				),
			]
		);
		$this->add_control(
			'sec_class',
			[
				'label'       => __( 'Section Class', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter Section Class', 'rashid' ),
			]
		);
		$this->add_control(
			'number',
			[
				'label'   => esc_html__( 'Number of post', 'roofer' ),
				'type'    => Controls_Manager::NUMBER,
				'default' => 3,
				'min'     => 1,
				'max'     => 100,
				'step'    => 1,
			]
		);
		$this->add_control(
			'cat_exclude',
			[
				'label'       => esc_html__( 'Exclude', 'roofer' ),
				'type'        => Controls_Manager::TEXT,
				'description' => esc_html__( 'Exclude categories, etc. by ID with comma separated.', 'roofer' ),
			]
		);
		$this->add_control(
			'query_order',
			[
				'label'   => esc_html__( 'Order', 'roofer' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'DESC',
				'options' => array(
					'DESc' => esc_html__( 'DESC', 'roofer' ),
					'ASC'  => esc_html__( 'ASC', 'roofer' ),
				),
			]
		);
		$this->add_control(
			'query_orderby',
			[
				'label'   => esc_html__( 'Order By', 'roofer' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'date',
				'options' => array(
					'date'       => esc_html__( 'Date', 'roofer' ),
					'title'      => esc_html__( 'Title', 'roofer' ),
					'menu_order' => esc_html__( 'Menu Order', 'roofer' ),
					'rand'       => esc_html__( 'Random', 'roofer' ),
				),
			]
		);
		$this->end_controls_section();
		
	}

	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$paged = roofer_set($_POST, 'paged') ? esc_attr($_POST['paged']) : 1;
		$this->add_render_attribute( 'wrapper', 'class', 'templatepath-roofer' );
		$args = array(
			'post_type'      => 'roofer_project',
			'posts_per_page' => roofer_set( $settings, 'number' ),
			'orderby'        => roofer_set( $settings, 'query_orderby' ),
			'order'          => roofer_set( $settings, 'query_order' ),
			'paged'         => $paged
		);
		$terms_array = explode(",",roofer_set( $settings, 'cat_exclude' ));
		if(roofer_set( $settings, 'cat_exclude' )) $args['tax_query'] = array(array('taxonomy' => 'project_cat','field' => 'id','terms' => $terms_array,'operator' => 'NOT IN',));
		$allowed_tags = wp_kses_allowed_html('post');
		$query = new \WP_Query( $args );
		$t = '';
		$data_filtration = '';
		$data_posts = '';
		if ( $query->have_posts() ) 
		{
		ob_start();
		?>
  
		<?php 
            $count = 0; 
            $fliteration = array();
            while( $query->have_posts() ): $query->the_post();
            global  $post;
            $meta = ''; //printr($meta);
            $meta1 = ''; //_WSH()->get_meta();
            $post_terms = get_the_terms( get_the_id(), 'project_cat');// printr($post_terms); exit();
            foreach( (array)$post_terms as $pos_term ) $fliteration[$pos_term->term_id] = $pos_term;
            $temp_category = get_the_term_list(get_the_id(), 'project_cat', '', ', ');
            
            $post_terms = wp_get_post_terms( get_the_id(), 'project_cat'); 
            $term_slug = '';
            if( $post_terms ) foreach( $post_terms as $p_term ) $term_slug .= $p_term->slug.' ';
        
            ?>
				<?php  if ( 'style1' === $settings['style'] ) : ?>	
					<div class="col-lg-<?php echo esc_attr($settings['column'], true );?> col-md-6 col-sm-6 col-12 masonry-item small-column all <?php echo esc_attr($term_slug); ?>">
							<div class="portfolio__block__one">
								<div class="inner-box">
									<figure class="image-box">
										<?php the_post_thumbnail(); ?>
									</figure>
									<div class="lower__content">
										<div class="view-btn"><a href="<?php echo esc_url(get_post_meta( get_the_id(), 'image_link', true ));?>" class="lightbox-image" data-fancybox="gallery"><span class="icon-18"></span></a></div>
										<div class="portfolio__block">
											<span><?php echo (get_post_meta( get_the_id(), 'meta_subtitle', true ));?></span>
											<h4><a href="<?php echo esc_url(get_post_meta( get_the_id(), 'page_link', true ));?>"><?php the_title(); ?></a></h4>
										</div>
									</div>
								</div>
							</div>
						</div>
				<?php endif;?>

				<?php  if ( 'style2' === $settings['style'] ) : ?>
					<div class="col-lg-<?php echo esc_attr($settings['column'], true );?> col-md-6 col-sm-6 col-12 masonry-item small-column all <?php echo esc_attr($term_slug); ?>">
						<div class="portfolio__block__one">
							<div class="inner-box">
								<figure class="image-box">
									<?php the_post_thumbnail(); ?>
								</figure>
								<div class="lower__content">
									<div class="view-btn"><a href="?php echo esc_url(get_post_meta( get_the_id(), 'image_link', true ));?>" class="lightbox-image" data-fancybox="gallery"><span class="icon-18"></span></a></div>
								</div>
							</div>
							<div class="portfolio__block">
							<span><?php echo (get_post_meta( get_the_id(), 'meta_subtitle', true ));?></span>
							<h4><a href="<?php echo esc_url(get_post_meta( get_the_id(), 'page_link', true ));?>"><?php the_title(); ?></a></h4>
							</div>
						</div>
					</div>
				<?php endif;?>
            <?php endwhile;?>

            <?php wp_reset_postdata();
            $data_posts = ob_get_contents();
            ob_end_clean();
            
            ob_start();?>
            
            <?php $terms = get_terms(array('project_cat')); ?>
           
			<!-- portfolio-section -->
			<?php  if ( 'style1' === $settings['style'] ) : ?>
				<section class="portfolio style__one see__pad p_relative ">
					<div class="sortable-masonry">
						<div class="filters">                                    
							<ul class="filter-tabs filter-btns clearfix">
								<li class="active filter" data-role="button" data-filter=".all"><?php esc_attr_e('All Works', 'roofer');?></li>
								<?php foreach( $fliteration as $t ): ?>
									<li class="filter" data-role="button" data-filter=".<?php echo esc_attr(roofer_set( $t, 'slug' )); ?>"><?php echo roofer_set( $t, 'name'); ?></li>
								<?php endforeach;?>
							</ul>
						</div>
						<div class="items-container row"> 
							<?php echo $data_posts; ?>
						</div>
					</div>
				</section>
			<?php endif;?>
        <!-- project-style-1 -->

		<?php  if ( 'style2' === $settings['style'] ) : ?> 
			<section class="portfolio style__one two see__pad p_relative ">
            <div class="auto_container">
                <div class="sortable-masonry">
                    <div class="filters">                                    
                        <ul class="filter-tabs filter-btns clearfix">
						<li class="active filter" data-role="button" data-filter=".all"><?php esc_attr_e('All Works', 'roofer');?></li>
                            <?php foreach( $fliteration as $t ): ?>
								<li class="filter" data-role="button" data-filter=".<?php echo esc_attr(roofer_set( $t, 'slug' )); ?>"><?php echo roofer_set( $t, 'name'); ?></li>
							<?php endforeach;?>
                        </ul>
                    </div>
                    <div class="items-container row"> 
						<?php echo $data_posts; ?>
                    </div>
                </div>
            </div>
        </section>

		<?php endif;?>
    	<?php }
	}

}
