<?php

namespace ROOFERPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Pricing_Tab extends Widget_Base {

	/**
	 * Get widget name. 
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'roofer_pricing_tab';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Pricing Tab', 'roofer' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fa fa-briefcase';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'roofer' ];
	}
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'pricing_tab',
			[
				'label' => esc_html__( 'Pricing Tab', 'roofer' ),
			]
		);
		$this->add_control(
			'sec_class',
			[
				'label'       => __( 'Section Class', 'roofer' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter Section Class', 'roofer' ),
			]
		);

		$this->end_controls_section();


		$this->start_controls_section(
			'content_section',
			[
				'label' => __( 'Slider Block', 'roofer' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
		  'repeat', 
			[
				'type' => Controls_Manager::REPEATER,
				'seperator' => 'before',
				'default' => 
					[
						['block_title' => esc_html__('Projects Completed', 'roofer')],
					],
				'fields' => 

					[	
						'block_title'=>
						[
							'name' => 'block_title',
							'label' => esc_html__('Title', 'rashid'),
							'type' => Controls_Manager::TEXTAREA,
							'default' => esc_html__('', 'rashid')
						],

						'block_bgimg'=>
						[
							'name' => 'block_bgimg',
							'label' => esc_html__('Background image', 'rashid'),
							'type' => Controls_Manager::MEDIA,
							'default' => ['url' => Utils::get_placeholder_image_src(),],
						],

						'block_bgimg1'=>
						[
							'name' => 'block_bgimg1',
							'label' => esc_html__('Background image', 'rashid'),
							'type' => Controls_Manager::MEDIA,
							'default' => ['url' => Utils::get_placeholder_image_src(),],
						],

						'block_subtitle'=>
						[
							'name' => 'block_subtitle',
							'label' => esc_html__('Sub Title', 'rashid'),
							'type' => Controls_Manager::TEXTAREA,
							'default' => esc_html__('', 'rashid')
						],

						'block_title1'=>
						[
							'name' => 'block_title1',
							'label' => esc_html__('Title', 'rashid'),
							'type' => Controls_Manager::TEXTAREA,
							'default' => esc_html__('', 'rashid')
						],

						'block_text'=>
						[
							'name' => 'block_text',
							'label' => esc_html__('Text', 'rashid'),
							'type' => Controls_Manager::TEXTAREA,
							'default' => esc_html__('', 'rashid')
						],

						'block_text1'=>
						[
							'name' => 'block_text1',
							'label' => esc_html__('Text', 'rashid'),
							'type' => Controls_Manager::TEXTAREA,
							'default' => esc_html__('', 'rashid')
						],

						'block_btnlink'=>
						[
						  'name' => 'block_btnlink',
						  'label' => __( 'Button Url', 'rashid' ),
						  'type' => Controls_Manager::URL,
						  'placeholder' => __( 'https://your-link.com', 'rashid' ),
						  'show_external' => true,
						  'default' => [
							'url' => '',
							'is_external' => true,
							'nofollow' => true,
						  ],
					   	],

						'block_button'=>
						[
							'name' => 'block_button',
							'label'       => __( 'Button', 'rashid' ),
							'type'        => Controls_Manager::TEXT,
							'dynamic'     => [
								'active' => true,
							],
							'placeholder' => __( 'Enter your Button Title', 'rashid' ),
							'default' => esc_html__('Read More', 'rashid'),
						],

						'block_bgimg2'=>
						[
							'name' => 'block_bgimg2',
							'label' => esc_html__('Background image', 'rashid'),
							'type' => Controls_Manager::MEDIA,
							'default' => ['url' => Utils::get_placeholder_image_src(),],
						],

						'block_bgimg3'=>
						[
							'name' => 'block_bgimg3',
							'label' => esc_html__('Background image', 'rashid'),
							'type' => Controls_Manager::MEDIA,
							'default' => ['url' => Utils::get_placeholder_image_src(),],
						],

						'block_subtitle1'=>
						[
							'name' => 'block_subtitle1',
							'label' => esc_html__('Sub Title', 'rashid'),
							'type' => Controls_Manager::TEXTAREA,
							'default' => esc_html__('', 'rashid')
						],

						'block_title2'=>
						[
							'name' => 'block_title2',
							'label' => esc_html__('Title', 'rashid'),
							'type' => Controls_Manager::TEXTAREA,
							'default' => esc_html__('', 'rashid')
						],

						'block_text2'=>
						[
							'name' => 'block_text2',
							'label' => esc_html__('Text', 'rashid'),
							'type' => Controls_Manager::TEXTAREA,
							'default' => esc_html__('', 'rashid')
						],

						'block_text3'=>
						[
							'name' => 'block_text3',
							'label' => esc_html__('Text', 'rashid'),
							'type' => Controls_Manager::TEXTAREA,
							'default' => esc_html__('', 'rashid')
						],

						'block_btnlink1'=>
						[
						  'name' => 'block_btnlink1',
						  'label' => __( 'Button Url', 'rashid' ),
						  'type' => Controls_Manager::URL,
						  'placeholder' => __( 'https://your-link.com', 'rashid' ),
						  'show_external' => true,
						  'default' => [
							'url' => '',
							'is_external' => true,
							'nofollow' => true,
						  ],
					   	],

						'block_button1'=>
						[
							'name' => 'block_button1',
							'label'       => __( 'Button', 'rashid' ),
							'type'        => Controls_Manager::TEXT,
							'dynamic'     => [
								'active' => true,
							],
							'placeholder' => __( 'Enter your Button Title', 'rashid' ),
							'default' => esc_html__('Read More', 'rashid'),
						],

						'block_bgimg4'=>
						[
							'name' => 'block_bgimg4',
							'label' => esc_html__('Background image', 'rashid'),
							'type' => Controls_Manager::MEDIA,
							'default' => ['url' => Utils::get_placeholder_image_src(),],
						],

						'block_bgimg5'=>
						[
							'name' => 'block_bgimg5',
							'label' => esc_html__('Background image', 'rashid'),
							'type' => Controls_Manager::MEDIA,
							'default' => ['url' => Utils::get_placeholder_image_src(),],
						],

						'block_subtitle2'=>
						[
							'name' => 'block_subtitle2',
							'label' => esc_html__('Sub Title', 'rashid'),
							'type' => Controls_Manager::TEXTAREA,
							'default' => esc_html__('', 'rashid')
						],

						'block_title3'=>
						[
							'name' => 'block_title3',
							'label' => esc_html__('Title', 'rashid'),
							'type' => Controls_Manager::TEXTAREA,
							'default' => esc_html__('', 'rashid')
						],

						'block_text4'=>
						[
							'name' => 'block_text4',
							'label' => esc_html__('Text', 'rashid'),
							'type' => Controls_Manager::TEXTAREA,
							'default' => esc_html__('', 'rashid')
						],

						'block_text5'=>
						[
							'name' => 'block_text5',
							'label' => esc_html__('Text', 'rashid'),
							'type' => Controls_Manager::TEXTAREA,
							'default' => esc_html__('', 'rashid')
						],

						'block_btnlink2'=>
						[
						  'name' => 'block_btnlink2',
						  'label' => __( 'Button Url', 'rashid' ),
						  'type' => Controls_Manager::URL,
						  'placeholder' => __( 'https://your-link.com', 'rashid' ),
						  'show_external' => true,
						  'default' => [
							'url' => '',
							'is_external' => true,
							'nofollow' => true,
						  ],
					   	],

						'block_button2'=>
						[
							'name' => 'block_button2',
							'label'       => __( 'Button', 'rashid' ),
							'type'        => Controls_Manager::TEXT,
							'dynamic'     => [
								'active' => true,
							],
							'placeholder' => __( 'Enter your Button Title', 'rashid' ),
							'default' => esc_html__('Read More', 'rashid'),
						],
						
					],

				'title_field' => '{{block_title}}',
			 ]
		);
		
		
		$this->end_controls_section();	
		
				
		
	}

	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	 
	protected function render() {
		$settings = $this->get_settings_for_display();
		$allowed_tags = wp_kses_allowed_html('post');
		?>
        	

<?php
	  echo '
	 <script>
 jQuery(document).ready(function($)
 {

//put the js code under this line 



//put the code above the line 

  });
</script>';


?>


  	<!-- pricing-one -->
  	<section class="pricing-one pricing-page-1 p_relative <?php echo esc_attr($settings['sec_class']);?>">
		<div class="auto_container">
			<div class="tabs-box">
				<div class="tab-btn-box p_relative d_block">
					<ul class="tab-btns tab-buttons clearfix p_relative">
						<?php foreach($settings['repeat'] as $key=>$item):?>
							<li class="tab-btn <?php if($key == 0) echo 'active-btn';?>" data-tab="#tab-<?php echo esc_attr($key);?>"><?php echo wp_kses($item['block_title'], $allowed_tags);?></li>
						<?php endforeach; ?>
					</ul>
				</div>
				<div class="tabs-content">
					<?php foreach($settings['repeat'] as $key=>$item):?>
						<div class="tab <?php if($key == 0) echo 'active-tab';?>" id="tab-<?php echo esc_attr($key);?>">
							<div class="row">
								<div class="col-lg-4 col-md-6 col-sm-6 col-12">
									<div class="price__content p_relative">
										<div class="image_layer shape-06" style="background-image:url(<?php echo wp_get_attachment_url($item['block_bgimg']['id']);?>)"></div>
										<div class="price__text p_relative">
											<div class="image_layer shape-55" style="background-image:url(<?php echo wp_get_attachment_url($item['block_bgimg1']['id']);?>)"></div>
											<h6><?php echo wp_kses($item['block_subtitle'], $allowed_tags);?></h6>
											<h2><?php echo wp_kses($item['block_title1'], $allowed_tags);?></h2>
											<p><?php echo wp_kses($item['block_text'], $allowed_tags);?></p>
										</div>
										<div class="price__list">
											<ul>
												<?php echo wp_kses($item['block_text1'], $allowed_tags);?>
											</ul>
										</div>
										<div class="price__btn">
											<a href="<?php echo esc_url($item['block_btnlink']['url']);?>"><?php echo wp_kses($item['block_button'], $allowed_tags);?></a>
										</div>
									</div>
								</div>
								<div class="col-lg-4 col-md-6 col-sm-6 col-12">
									<div class="price__content p_relative">
										<div class="image_layer shape-06" style="background-image:url(<?php echo wp_get_attachment_url($item['block_bgimg2']['id']);?>)"></div>
										<div class="price__text p_relative">
											<div class="image_layer shape-55" style="background-image:url(<?php echo wp_get_attachment_url($item['block_bgimg3']['id']);?>)"></div>
											<h6><?php echo wp_kses($item['block_subtitle1'], $allowed_tags);?></h6>
											<h2><?php echo wp_kses($item['block_title2'], $allowed_tags);?></h2>
											<p><?php echo wp_kses($item['block_text2'], $allowed_tags);?></p>
										</div>
										<div class="price__list">
											<ul>
												<?php echo wp_kses($item['block_text3'], $allowed_tags);?>
											</ul>
										</div>
										<div class="price__btn">
											<a href="<?php echo esc_url($item['block_btnlink1']['url']);?>"><?php echo wp_kses($item['block_button1'], $allowed_tags);?></a>
										</div>
									</div>
								</div>
								<div class="col-lg-4 col-md-6 col-sm-6 col-12">
									<div class="price__content p_relative">
										<div class="image_layer shape-06" style="background-image:url(<?php echo wp_get_attachment_url($item['block_bgimg4']['id']);?>)"></div>
										<div class="price__text p_relative">
											<div class="image_layer shape-55" style="background-image:url(<?php echo wp_get_attachment_url($item['block_bgimg5']['id']);?>)"></div>
											<h6><?php echo wp_kses($item['block_subtitle2'], $allowed_tags);?></h6>
											<h2><?php echo wp_kses($item['block_title3'], $allowed_tags);?></h2>
											<p><?php echo wp_kses($item['block_text4'], $allowed_tags);?></p>
										</div>
										<div class="price__list">
											<ul>
												<?php echo wp_kses($item['block_text5'], $allowed_tags);?>
											</ul>
										</div>
										<div class="price__btn">
											<a href="<?php echo esc_url($item['block_btnlink2']['url']);?>"><?php echo wp_kses($item['block_button2'], $allowed_tags);?></a>
										</div>
									</div>
								</div>
							</div>
						</div>
					<?php endforeach; ?>
				</div>
			</div>
		</div>
	</section>
    <!-- pricing-one end -->





             
		<?php 
	}

}