<?php

namespace ROOFERPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Service_Block_Two extends Widget_Base {

	/**
	 * Get widget name. 
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'roofer_service_block_two';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Service Block Two', 'roofer' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fa fa-briefcase';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'roofer' ];
	}
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'service_block_two',
			[
				'label' => esc_html__( 'Service Block Two', 'roofer' ),
			]
		);
		$this->add_control(
			'sec_class',
			[
				'label'       => __( 'Section Class', 'roofer' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter Section Class', 'roofer' ),
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'content_section',
			[
				'label' => __( 'Slider Block', 'roofer' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
		  'repeat', 
			[
				'type' => Controls_Manager::REPEATER,
				'seperator' => 'before',
				'default' => 
					[
						['block_title' => esc_html__('Projects Completed', 'roofer')],
					],
				'fields' => 

					[	
							'block_bgimg'=>
						[
							'name' => 'block_bgimg',
							'label' => esc_html__('Background image', 'rashid'),
							'type' => Controls_Manager::MEDIA,
							'default' => ['url' => Utils::get_placeholder_image_src(),],
						],

						'block_bgimg1'=>
						[
							'name' => 'block_bgimg1',
							'label' => esc_html__('Background image', 'rashid'),
							'type' => Controls_Manager::MEDIA,
							'default' => ['url' => Utils::get_placeholder_image_src(),],
						],

						'block_bgimg2'=>
						[
							'name' => 'block_bgimg2',
							'label' => esc_html__('Background image', 'rashid'),
							'type' => Controls_Manager::MEDIA,
							'default' => ['url' => Utils::get_placeholder_image_src(),],
						],

						'block_bgimg3'=>
						[
							'name' => 'block_bgimg3',
							'label' => esc_html__('Background image', 'rashid'),
							'type' => Controls_Manager::MEDIA,
							'default' => ['url' => Utils::get_placeholder_image_src(),],
						],

						'block_icons'=>
						[
							'name' => 'block_icons',
							'label' => esc_html__('Enter The icons', 'rashid'),
							'type' => Controls_Manager::ICONS,							
						],

						'block_btnlink'=>
						[
							'name' => 'block_btnlink',
							'label' => __( 'Button Url', 'rashid' ),
							'type' => Controls_Manager::URL,
							'placeholder' => __( 'https://your-link.com', 'rashid' ),
							'show_external' => true,
							'default' => [
							  'url' => '',
							  'is_external' => true,
							  'nofollow' => true,
							],
						],

						'block_title'=>
						[
							'name' => 'block_title',
							'label' => esc_html__('Title', 'rashid'),
							'type' => Controls_Manager::TEXTAREA,
							'default' => esc_html__('', 'rashid')
						],

						'block_text'=>
						[
							'name' => 'block_text',
							'label' => esc_html__('Text', 'rashid'),
							'type' => Controls_Manager::TEXTAREA,
							'default' => esc_html__('', 'rashid')
						],

						'block_btnlink'=>
						[
							'name' => 'block_btnlink',
							'label' => __( 'Button Url', 'rashid' ),
							'type' => Controls_Manager::URL,
							'placeholder' => __( 'https://your-link.com', 'rashid' ),
							'show_external' => true,
							'default' => [
							  'url' => '',
							  'is_external' => true,
							  'nofollow' => true,
							],
						],

						'block_button'=>
						[
							'name' => 'block_button',
							'label'       => __( 'Button', 'rashid' ),
							'type'        => Controls_Manager::TEXT,
							'dynamic'     => [
								'active' => true,
							],
							'placeholder' => __( 'Enter your Button Title', 'rashid' ),
							'default' => esc_html__('Read More', 'rashid'),
						],

						'block_icons1'=>
						[
							'name' => 'block_icons1',
							'label' => esc_html__('Enter The icons', 'rashid'),
							'type' => Controls_Manager::ICONS,							
						],

						'block_icons2'=>
						[
							'name' => 'block_icons2',
							'label' => esc_html__('Enter The icons', 'rashid'),
							'type' => Controls_Manager::ICONS,							
						],

					],

				'title_field' => '{{block_title}}',
			 ]
		);

		$this->end_controls_section();
		
				
		
	}

	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	 
	protected function render() {
		$settings = $this->get_settings_for_display();
		$allowed_tags = wp_kses_allowed_html('post');
		?>
        	

<?php
	  echo '
	 <script>
 jQuery(document).ready(function($)
 {

//put the js code under this line 
// service-carousel

	if ($(".service-carousel").length) {
        $(".service-carousel").owlCarousel({
            loop:true,
			margin:30,
			nav:true,
			smartSpeed: 1000,
			autoplay: 6000,
            responsive:{
                0:{
                    items:1
                },
                600:{
                    items:2,
                },
                800:{
                    items:2,
                },
				1024:{
					items:3,
				},
                1200:{
                    items:4
                }
            }
        });
    }

//put the code above the line 

  });
</script>';


?>

	<!-- our-service-four -->
	<section class="service__four p_relative <?php echo esc_attr($settings['sec_class']);?>">
		<div class="service__four__content">
			<div class="auto_container">
				<div class="service__four__slider">
					<div class="service-carousel owl-carousel owl-theme  dots-style-one owl-loaded owl-drag">
						<?php foreach($settings['repeat'] as $key=>$item):?>
							<div class="inner__content__four">
								<div class="service__content__four">
									<div class="image_layer">
										<div class="image__hover__bg__one" style="background-image:url(<?php echo wp_get_attachment_url($item['block_bgimg']['id']);?>) ;"></div>
										<div class="image__hover__bg__two" style="background-image:url(<?php echo wp_get_attachment_url($item['block_bgimg1']['id']);?>) ;"></div>
									</div>
									<div class="lower__content__four">
										<div class="icon__box p_ralative">
											<div class="icon__hover__bg__one" style="background-image:url(<?php echo wp_get_attachment_url($item['block_bgimg2']['id']);?>) ;"></div>
											<div class="icon__hover__bg__two" style="background-image:url(<?php echo wp_get_attachment_url($item['block_bgimg3']['id']);?>) ;"></div>
											<div class="icon__outer">
												<div class="icon__bg">
													<span class="<?php echo str_replace("icon ", " ", esc_attr( $item['block_icons']['value']));?>"></span>
												</div>
											</div>
										</div>
										<div class="service__text">
											<h4><a href="<?php echo esc_url($item['block_btnlink']['url']);?>"><?php echo wp_kses($item['block_title'], $allowed_tags);?></a></h4>
											<p><?php echo wp_kses($item['block_text'], $allowed_tags);?></p>
										</div>
										<div class="more__btn">
											<a href="<?php echo esc_url($item['block_btnlink1']['url']);?>"><?php echo wp_kses($item['block_button'], $allowed_tags);?> <span class="<?php echo str_replace("icon ", " ", esc_attr( $item['block_icons1']['value']));?>"></span> <span class="<?php echo str_replace("icon ", " ", esc_attr( $item['block_icons2']['value']));?>"></span></a>
										</div>
									</div>
								</div>
							</div>
						<?php endforeach; ?>
					</div>
				</div>
			</div>
		</div>
	</section>
	<!-- our-service-four-end -->

             
		<?php 
	}

}