<?php

namespace ROOFERPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Service_Tab2 extends Widget_Base {

	/**
	 * Get widget name. 
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'roofer_service_tab2';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Service Tab2', 'roofer' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fa fa-briefcase';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'roofer' ];
	}
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'service_tab2',
			[
				'label' => esc_html__( 'Service Tab2 ', 'roofer' ),
			]
		);
		$this->add_control(
			'sec_class',
			[
				'label'       => __( 'Section Class', 'roofer' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter Section Class', 'roofer' ),
			]
		);

		$this->add_control(
			'title',
			[
				'label'       => __( 'Title', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your title', 'rashid' ),
			]
		);


		$this->add_control(
			'subtitle',
			[
				'label'       => __( 'Sub Title', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Sub title', 'rashid' ),
			]
		);

		$this->end_controls_section();


		$this->start_controls_section(
			'content_section',
			[
				'label' => __( 'Slider Block', 'roofer' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
		  'repeat', 
			[
				'type' => Controls_Manager::REPEATER,
				'seperator' => 'before',
				'default' => 
					[
						['block_title' => esc_html__('Projects Completed', 'roofer')],
					],
				'fields' => 

					[	
						'block_bgimg'=>
						[
							'name' => 'block_bgimg',
							'label' => esc_html__('Background image', 'rashid'),
							'type' => Controls_Manager::MEDIA,
							'default' => ['url' => Utils::get_placeholder_image_src(),],
						],

						'block_bgimg1'=>
						[
							'name' => 'block_bgimg1',
							'label' => esc_html__('Background image', 'rashid'),
							'type' => Controls_Manager::MEDIA,
							'default' => ['url' => Utils::get_placeholder_image_src(),],
						],


						'block_icons'=>
						[
							'name' => 'block_icons',
							'label' => esc_html__('Enter The icons', 'rashid'),
							'type' => Controls_Manager::ICONS,							
						],

						'block_title'=>
						[
							'name' => 'block_title',
							'label' => esc_html__('Title', 'rashid'),
							'type' => Controls_Manager::TEXTAREA,
							'default' => esc_html__('', 'rashid')
						],

						'block_image3'=>
						[
							'name' => 'block_image3',
							'label' => __( 'Image', 'rashid' ),
							'type' => Controls_Manager::MEDIA,
							'default' => ['url' => Utils::get_placeholder_image_src(),],
						],
						  
						'block_alt_text3'=>
						[
						'name' => 'block_alt_text3',
						'label' => esc_html__('Image Text', 'rashid'),
						'type' => Controls_Manager::TEXTAREA,
						'default' => esc_html__('', 'rashid')
						],

						'block_subtitle'=>
						[
							'name' => 'block_subtitle',
							'label' => esc_html__('Sub Title', 'rashid'),
							'type' => Controls_Manager::TEXTAREA,
							'default' => esc_html__('', 'rashid')
						],

						'block_text'=>
						[
							'name' => 'block_text',
							'label' => esc_html__('Text', 'rashid'),
							'type' => Controls_Manager::TEXTAREA,
							'default' => esc_html__('', 'rashid')
						],

						'block_text1'=>
						[
							'name' => 'block_text1',
							'label' => esc_html__('Text', 'rashid'),
							'type' => Controls_Manager::TEXTAREA,
							'default' => esc_html__('', 'rashid')
						],

						'block_btnlink'=>
						[
						  'name' => 'block_btnlink',
						  'label' => __( 'Button Url', 'rashid' ),
						  'type' => Controls_Manager::URL,
						  'placeholder' => __( 'https://your-link.com', 'rashid' ),
						  'show_external' => true,
						  'default' => [
							'url' => '',
							'is_external' => true,
							'nofollow' => true,
						  ],
					   	],

						'block_button'=>
						[
							'name' => 'block_button',
							'label'       => __( 'Button', 'rashid' ),
							'type'        => Controls_Manager::TEXT,
							'dynamic'     => [
								'active' => true,
							],
							'placeholder' => __( 'Enter your Button Title', 'rashid' ),
							'default' => esc_html__('Read More', 'rashid'),
						],

						'block_btnlink'=>
						[
						  'name' => 'block_btnlink',
						  'label' => __( 'Button Url', 'rashid' ),
						  'type' => Controls_Manager::URL,
						  'placeholder' => __( 'https://your-link.com', 'rashid' ),
						  'show_external' => true,
						  'default' => [
							'url' => '',
							'is_external' => true,
							'nofollow' => true,
						  ],
					   	],
					],

				'title_field' => '{{block_title}}',
			 ]
		);
		
		
		$this->end_controls_section();	
		
				
		
	}

	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	 
	protected function render() {
		$settings = $this->get_settings_for_display();
		$allowed_tags = wp_kses_allowed_html('post');
		?>
        	

<?php
	  echo '
	 <script>
 jQuery(document).ready(function($)
 {

//put the js code under this line 



//put the code above the line 

  });
</script>';


?>


		 <!-- service-section -->
 		<section class="service__section three see__pad <?php echo esc_attr($settings['sec_class']);?>">
            <div class="service__content p_relative">
                <div class="auto_container">
                    <div class="title text-center">
                        <div class="sub__title">
							<h6><?php echo $settings['subtitle'];?></h6>
                        </div>
                        <div class="main__title">
							<h2><?php echo $settings['title'];?></h2>
                        </div>
                    </div>
                    <div class="service__tab__section">
                        <div class="tabs-box three">
                            <div class="tab-btn-box p_relative">
                                <ul class="tab-btns three tab-buttons clearfix">
								<?php foreach($settings['repeat'] as $key=>$item):?>
                                    <li class="tab-btn <?php if($key == 0) echo 'active-btn';?>" data-tab="#tab-<?php echo esc_attr($key);?>">
                                        <div class="inner__tab">
                                            <div class="icon__hover__one" style="background-image:url(<?php echo wp_get_attachment_url($item['block_bgimg']['id']);?>) ;"></div>
                                            <div class="icon__hover__two" style="background-image:url(<?php echo wp_get_attachment_url($item['block_bgimg1']['id']);?>) ;"></div>
                                            <div class="tab__content__three">
                                                <div class="tab__content__icon">
                                                    <i class="<?php echo str_replace("icon ", " ", esc_attr( $item['block_icons']['value']));?>"></i>
                                                </div>
                                                <div class="tab__content__text">
                                                    <span class="tab___all"> <?php echo wp_kses($item['block_title'], $allowed_tags);?> </span>
                                                </div>
                                            </div>
                                        </div>
                                    </li>
									<?php endforeach; ?>
                                </ul>
                            </div>
                            <div class="tabs-content wow fadeInUp animated animated" data-wow-delay="00ms" data-wow-duration="1500ms" style="visibility: visible; animation-duration: 1500ms; animation-delay: 0ms; animation-name: fadeInUp;">
							<?php foreach($settings['repeat'] as $key=>$item):?>
                                <div class="tab <?php if($key == 0) echo 'active-tab';?>" id="tab-<?php echo esc_attr($key);?>">
                                    <div class="row">
                                        <div class="col-lg-6 col-md-12 pe-xl-4">
                                            <div class="tab__left__content">
												<figure class="image">
													<?php if(wp_get_attachment_url($item['block_image3']['id'])): ?>
													<img src="<?php echo wp_get_attachment_url($item['block_image3']['id']);?>" alt="<?php echo wp_kses($item['block_alt_text3'], $allowed_tags);?>">
													<?php else :?>
													<div class="noimage"></div>
													<?php endif;?>
												</figure>
                                            </div>
                                        </div>
                                        <div class="col-lg-6 col-md-12 ps-xl-4">
                                            <div class="tab__right__content">
												<h4><?php echo wp_kses($item['block_subtitle'], $allowed_tags);?></h4>
                                                <div class="tab__text">
													<p><?php echo wp_kses($item['block_text'], $allowed_tags);?></p>
                                                </div>
                                                <div class="tab__list">
                                                    <ul>
														<?php echo wp_kses($item['block_text1'], $allowed_tags);?>
                                                    </ul>
                                                </div>
                                                <div class="tab__btn">
                                                    <a class="btn-one" href="<?php echo esc_url($item['block_btnlink']['url']);?>">
                                                        <em>
                                                            <i></i>
                                                            <i></i>
                                                            <i></i>
                                                            <i></i>
                                                            <i></i>
                                                            <i></i>
                                                            <i></i>
                                                        </em>
                                                        <span><?php echo wp_kses($item['block_button'], $allowed_tags);?></span>
                                                    </a>
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                                <?php endforeach; ?>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>
        <!-- service-section-end -->





             
		<?php 
	}

}