<?php

namespace ROOFERPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Testimonials_Slider extends Widget_Base {

	/**
	 * Get widget name. 
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'roofer_testimonials_slider';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Testimonials Slider', 'roofer' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fa fa-briefcase';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'roofer' ];
	}
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'testimonials_slider',
			[
				'label' => esc_html__( 'Testimonials Slider', 'roofer' ),
			]
		);
		$this->add_control(
			'sec_class',
			[
				'label'       => __( 'Section Class', 'roofer' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter Section Class', 'roofer' ),
			]
		);

		$this->add_control(
			'bgimg',
			[
				'label' => esc_html__('Background image', 'rashid'),
				'type' => Controls_Manager::MEDIA,
				'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
		);	

		$this->add_control(
			'bgimg1',
			[
				'label' => esc_html__('Background image', 'rashid'),
				'type' => Controls_Manager::MEDIA,
				'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
		);	


		$this->add_control(
			'subtitle',
			[
				'label'       => __( 'Sub Title', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Sub title', 'rashid' ),
			]
		);

		$this->add_control(
			'title',
			[
				'label'       => __( 'Title', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your title', 'rashid' ),
			]
		);


	$this->add_control(
			'text',
			[
				'label'       => __( 'Description Text', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Description', 'rashid' ),
			]
		);
		

		$this->add_control(
			'bgimg2',
			[
				'label' => esc_html__('Background image', 'rashid'),
				'type' => Controls_Manager::MEDIA,
				'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
		);	

		$this->add_control(
			'image',
				[
				  'label' => __( 'Image', 'rashid' ),
				  'type' => Controls_Manager::MEDIA,
				  'default' => ['url' => Utils::get_placeholder_image_src(),],
				]
		);	
		
		$this->add_control(
			'alt_text',
			[
				'label'       => __( 'Alt text', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Description', 'rashid' ),
			]
		);

		$this->end_controls_section();


		$this->start_controls_section(
			'content_section',
			[
				'label' => __( 'Slider Block', 'roofer' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
		  'repeat', 
			[
				'type' => Controls_Manager::REPEATER,
				'seperator' => 'before',
				'default' => 
					[
						['block_title' => esc_html__('Projects Completed', 'roofer')],
					],
				'fields' => 

					[	

						'block_image'=>

						[
							'name' => 'block_image',
							'label' => __( 'Image', 'rashid' ),
							'type' => Controls_Manager::MEDIA,
							'default' => ['url' => Utils::get_placeholder_image_src(),],
						  ],
						  
						  'block_alt_text'=>

						  [
						  'name' => 'block_alt_text',
						  'label' => esc_html__('Image Text', 'rashid'),
						  'type' => Controls_Manager::TEXTAREA,
						  'default' => esc_html__('', 'rashid')
						  ],	

						  'block_text'=>

						  [
							'name' => 'block_text',
							'label' => esc_html__('Text', 'rashid'),
							'type' => Controls_Manager::TEXTAREA,
							'default' => esc_html__('', 'rashid')
						],

						'block_title'=>

						[
							'name' => 'block_title',
							'label' => esc_html__('Title', 'rashid'),
							'type' => Controls_Manager::TEXTAREA,
							'default' => esc_html__('', 'rashid')
						],

						'block_subtitle'=>
						[
							'name' => 'block_subtitle',
							'label' => esc_html__('Sub Title', 'rashid'),
							'type' => Controls_Manager::TEXTAREA,
							'default' => esc_html__('', 'rashid')
						],

						'block_icons'=>

						[
							'name' => 'block_icons',
							'label' => esc_html__('Enter The icons', 'rashid'),
							'type' => Controls_Manager::ICONS,							
						],


					],

				'title_field' => '{{block_title}}',
			 ]
		);
		
		
		$this->end_controls_section();	
		
				
		
	}

	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	 
	protected function render() {
		$settings = $this->get_settings_for_display();
		$allowed_tags = wp_kses_allowed_html('post');
		?>
        	

<?php
	  echo '
	 <script>
 jQuery(document).ready(function($)
 {

//put the js code under this line 

if ($(".two-item-carousel").length) {
	var twoItemCarousel = new Swiper(".two-item-carousel", {
		preloadImages: false,
		loop: true,
		grabCursor: true,
		centeredSlides: false,
		resistance: true,
		resistanceRatio: 0.6,
		slidesPerView: 1,
		speed: 1400,
		spaceBetween: 30,
		parallax: false,
		effect: "slide",
		active: "active",
		autoplay: {
			delay: 800000000000,
			disableOnInteraction: false
		},
		navigation: {
			nextEl: ".button_next",
			prevEl: ".button_prev",
		},
		pagination: {
			el: ".slider__pagination",
			clickable: true,
		},
		breakpoints: {
			991: {
			  slidesPerView: 1,
			},
			640: {
			  slidesPerView: 1,
			}, 
		}
	});
}
//put the code above the line 

  });
</script>';


?>

<section class="testimonials__section p_relative <?php echo esc_attr($settings['sec_class']);?>">
	<div class="anim-icon">
		<div class="parallax-scene parallax-scene-3 " >
			<?php  if ( esc_url($settings['bgimg']['id']) ) : ?>
			<div data-depth="0.30" class="icon layer-bg" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg']['id']);?>);"></div>
			<?php else :?>	
			<div class="noimage"></div>
			<?php endif;?>
		</div>

		<?php  if ( esc_url($settings['bgimg1']['id']) ) : ?>
		<div class="icon icon-03 wow zoomIn animated" data-wow-delay="100ms" data-wow-duration="1500ms" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg1']['id']);?>);"></div>
		<?php else :?>	
		<div class="noimage"></div>
		<?php endif;?>
		
	</div>
	<div class="auto_container">
		<div class="testimonials__content p_relative">
			<div class="row">
				<div class="col-xl-4 col-lg-6 col-md-6 col-sm-12">
					<div class="testimonials__content__one">
						<div class="title">
							<div class="sub__title">
								<h6><?php echo $settings['subtitle'];?></h6>
							</div>
							<div class="main__title">
								<h2><?php echo $settings['title'];?></h2>
							</div>
						</div>
						<div class="testimonials__text">
							<p><?php echo $settings['text'];?></p>
						</div>
						<div class="slider_dots">
							<div class="slider_control">
								<div class="slider__pagination"></div>
							</div>
						</div>
					</div>
				</div>
				<div class="col-xl-5 col-lg-6 col-md-6 col-sm-12">
					<div class="testimonials__middle">
						<?php  if ( esc_url($settings['bgimg2']['id']) ) : ?>
						<div class="image__layer" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg2']['id']);?>);"></div>
						<?php else :?>	
						<div class="noimage"></div>
						<?php endif;?>
						<div class="swiper-container two-item-carousel">
							<div class="swiper-wrapper">
							<?php foreach($settings['repeat'] as $item):?>	
								<div class="swiper-slide testimonials__block__one">
									<div class="testimonials__info">
										<div class="authore__img">
											<figure class="image">
											<?php if(wp_get_attachment_url($item['block_image']['id'])): ?>
											<img src="<?php echo wp_get_attachment_url($item['block_image']['id']);?>" alt="<?php echo wp_kses($item['block_alt_text'], $allowed_tags);?>">
											<?php else :?>
											<div class="noimage"></div>
											<?php endif;?>
											</figure>
										</div>
										<div class="testimonials__text">
											<p><?php echo wp_kses($item['block_text'], $allowed_tags);?></p>
										</div>
										<div class="authore__info">
											<h5><?php echo wp_kses($item['block_title'], $allowed_tags);?></h5>
											<p><?php echo wp_kses($item['block_subtitle'], $allowed_tags);?></p>
										</div>
										<div class="quote">
											<span class="<?php echo str_replace("icon ", " ", esc_attr( $item['block_icons']['value']));?>"></span>
										</div>
									</div>
								</div>
							<?php endforeach; ?>
							</div>
						</div>
					</div>
				</div>
			</div>
			<div class="test__right__image wow slideInUp animated" data-wow-delay="100ms" data-wow-duration="1500ms">
				<figure class="image">
				<?php  if ( esc_url($settings['image']['id']) ) : ?>   
				<img src="<?php echo wp_get_attachment_url($settings['image']['id']);?>" alt="<?php echo esc_attr($settings['alt_text']);?>"/>
				<?php else :?>
				<div class="noimage"></div>
				<?php endif;?>
				</figure>
			</div>
		</div>
	</div>
</section>






		<?php 
	}

}