<?php

namespace ROOFERPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Testimonials_Slider_Two extends Widget_Base {

	/**
	 * Get widget name. 
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'roofer_testimonials_slider_two';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Testimonials Slider Two', 'roofer' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fa fa-briefcase';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'roofer' ];
	}
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'testimonials_slider_two',
			[
				'label' => esc_html__( 'Testimonials Slider Two', 'roofer' ),
			]
		);
		$this->add_control(
			'sec_class',
			[
				'label'       => __( 'Section Class', 'roofer' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter Section Class', 'roofer' ),
			]
		);

		$this->end_controls_section();


		$this->start_controls_section(
			'content_section',
			[
				'label' => __( 'Slider Block', 'roofer' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
		  'repeat', 
			[
				'type' => Controls_Manager::REPEATER,
				'seperator' => 'before',
				'default' => 
					[
						['block_title' => esc_html__('Projects Completed', 'roofer')],
					],
				'fields' => 

					[	

							'block_image'=>
						[
							'name' => 'block_image',
							'label' => __( 'Image', 'rashid' ),
							'type' => Controls_Manager::MEDIA,
							'default' => ['url' => Utils::get_placeholder_image_src(),],
						],

							'block_image1'=>
						[
							'name' => 'block_image1',
							'label' => __( 'Image', 'rashid' ),
							'type' => Controls_Manager::MEDIA,
							'default' => ['url' => Utils::get_placeholder_image_src(),],
						],
						  
						  'block_alt_text'=>
						[
						  'name' => 'block_alt_text',
						  'label' => esc_html__('Image Text', 'rashid'),
						  'type' => Controls_Manager::TEXTAREA,
						  'default' => esc_html__('', 'rashid')
						],


						  'block_text'=>
						[
							'name' => 'block_text',
							'label' => esc_html__('Text', 'rashid'),
							'type' => Controls_Manager::TEXTAREA,
							'default' => esc_html__('', 'rashid')
						],

						'block_title'=>

						[
							'name' => 'block_title',
							'label' => esc_html__('Title', 'rashid'),
							'type' => Controls_Manager::TEXTAREA,
							'default' => esc_html__('', 'rashid')
						],

						'block_text1'=>

						[
						  'name' => 'block_text1',
						  'label' => esc_html__('Text', 'rashid'),
						  'type' => Controls_Manager::TEXTAREA,
						  'default' => esc_html__('', 'rashid')
					  ],

						'block_icons'=>

						[
							'name' => 'block_icons',
							'label' => esc_html__('Enter The icons', 'rashid'),
							'type' => Controls_Manager::ICONS,							
						],


					],

				'title_field' => '{{block_title}}',
			 ]
		);
		
		
		$this->end_controls_section();	
		
				
		
	}

	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	 
	protected function render() {
		$settings = $this->get_settings_for_display();
		$allowed_tags = wp_kses_allowed_html('post');
		?>
        	

<?php
	  echo '
	 <script>
 jQuery(document).ready(function($)
 {

//put the js code under this line 

// testimonials-carousel-two
	if ($(".testimonials-carousel-two").length) {
        $(".testimonials-carousel-two").owlCarousel({
            loop:true,
			margin:24,
			nav:true,
			smartSpeed: 1000,
			autoplay: 6000,
            responsive:{
                0:{
                    items:1
                },
                600:{
                    items:2,
                },
                800:{
                    items:2,
                },
                1024:{
                    items:3
                }
            }
        });
    }
//put the code above the line 

  });
</script>';


?>


<!-- testimonials-section -->
<section class="testimonials__section three p_relative <?php echo esc_attr($settings['sec_class']);?>">
	<div class="auto_container">
		<div class="testimonials__content p_relative">		
			<div class="testimonials-carousel-two owl-carousel owl-theme  dots-style-one owl-loaded owl-drag">
			<?php foreach($settings['repeat'] as $item):?>	
				<div class="testimonials__middle">
					<div class="image__layer" style="background-image:url(<?php echo wp_get_attachment_url($item['block_image']['id']);?>)"></div>
					<div class="testimonials__block__one">
						<div class="testimonials__info">
							<div class="authore__img">
								<figure class="image">
									<?php if(wp_get_attachment_url($item['block_image1']['id'])): ?>
									<img src="<?php echo wp_get_attachment_url($item['block_image1']['id']);?>" alt="<?php echo wp_kses($item['block_alt_text'], $allowed_tags);?>">
									<?php else :?>
									<div class="noimage"></div>
									<?php endif;?>
								</figure>
							</div>
							<div class="testimonials__text">
								<p><?php echo wp_kses($item['block_text'], $allowed_tags);?></p>
							</div>
							<div class="authore__info">
								<h5><?php echo wp_kses($item['block_title'], $allowed_tags);?></h5>
								<p><?php echo wp_kses($item['block_text1'], $allowed_tags);?></p>
							</div>
							<div class="quote">
								<span class="<?php echo str_replace("icon ", " ", esc_attr( $item['block_icons']['value']));?>"></span>
							</div>
						</div>
					</div>
				</div>
				<?php endforeach; ?>					
			</div>
			
		</div>
	</div>
</section>
<!-- testimonials-section-end -->



		<?php 
	}

}